@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -100,7 +100,7 @@ public abstract class AbstractRubyMethod extends RubyObject implements DataType
 
     @JRubyMethod(name = "owner")
     public IRubyObject owner(ThreadContext context) {
-        return method.getDefinedClass();
+        return implementationModule;
     }
 
     @JRubyMethod(name = "source_location")
