@@ -2,14 +2,18 @@ package org.jruby;
 
 public enum CompatVersion {
 
-    RUBY1_8, RUBY1_9, RUBY2_0, BOTH;
+    @Deprecated RUBY1_8,
+    @Deprecated RUBY1_9,
+    @Deprecated RUBY2_0,
+    @Deprecated RUBY2_1,
+    @Deprecated BOTH;
 
     public boolean is1_9() {
-        return this == RUBY1_9 || this == RUBY2_0;
+        return this == RUBY1_9 || this == RUBY2_0 || this == RUBY2_1;
     }
 
     public boolean is2_0() {
-        return this == RUBY2_0;
+        return this == RUBY2_0 || this == RUBY2_1;
     }
 
     public static CompatVersion getVersionFromString(String compatString) {
@@ -25,6 +29,10 @@ public enum CompatVersion {
             return CompatVersion.RUBY2_0;
         } else if (compatString.equalsIgnoreCase("2.0")) {
             return CompatVersion.RUBY2_0;
+        } else if (compatString.equalsIgnoreCase("RUBY2_1")) {
+            return CompatVersion.RUBY2_1;
+        } else if (compatString.equalsIgnoreCase("2.1")) {
+            return CompatVersion.RUBY2_1;
         } else {
             return null;
         }
@@ -34,6 +42,7 @@ public enum CompatVersion {
         if (runtimeVersion == RUBY1_8) return methodVersion == RUBY1_8 || methodVersion == BOTH;
         if (runtimeVersion == RUBY1_9) return methodVersion == RUBY1_9 || methodVersion == BOTH;
         if (runtimeVersion == RUBY2_0) return methodVersion == RUBY1_9 || methodVersion == RUBY2_0 || methodVersion == BOTH;
+        if (runtimeVersion == RUBY2_1) return methodVersion == RUBY1_9 || methodVersion == RUBY2_0 || methodVersion == RUBY2_1 || methodVersion == BOTH;
         return false;
     }
 }
