@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -420,7 +420,7 @@ public class RubyBignum extends RubyInteger {
             if (slash) {
                 return RubyFloat.newFloat(runtime, div);
             } else {
-                return RubyNumeric.dbl2num(runtime, div);
+                return RubyNumeric.dbl2ival(runtime, div);
             }
         } else {
             return coerceBin(context, slash ? sites(context).op_quo : sites(context).div, other);
@@ -634,7 +634,7 @@ public class RubyBignum extends RubyInteger {
         if (Double.isInfinite(pow)) {
             return RubyFloat.newFloat(runtime, pow);
         }
-        return RubyNumeric.dbl2num(runtime, pow);
+        return RubyNumeric.dbl2ival(runtime, pow);
     }
 
     /** rb_big_and
