@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -68,7 +68,6 @@ import org.jruby.runtime.ObjectAllocator;
 import org.jruby.runtime.ThreadContext;
 import org.jruby.runtime.Visibility;
 import org.jruby.runtime.builtin.IRubyObject;
-import org.jruby.runtime.callsite.RespondToCallSite;
 import org.jruby.util.ByteList;
 import org.jruby.util.Numeric;
 
@@ -439,12 +438,9 @@ public class RubyComplex extends RubyNumeric {
     }
 
     private static boolean responds_to_to_c(ThreadContext context, IRubyObject obj) {
-        return respond_to_to_c.respondsTo(context, obj, obj);
+        return sites(context).respond_to_to_c.respondsTo(context, obj, obj);
     }
 
-    // TODO: wasn't sure whether to put this on NumericSites, here for now - should move
-    static final RespondToCallSite respond_to_to_c = new RespondToCallSite("to_c");
-
     /** nucomp_s_convert
      * 
      */
@@ -1032,7 +1028,7 @@ public class RubyComplex extends RubyNumeric {
             } else {
                 si = match.op_aref19(RubyFixnum.three(runtime));
                 IRubyObject t = match.op_aref19(RubyFixnum.four(runtime));
-                if (t.isNil()) t = runtime.newString(RubyFixnum.SINGLE_CHAR_BYTELISTS19['1']);
+                if (t.isNil()) t = runtime.newString(RubyInteger.SINGLE_CHAR_BYTELISTS['1']);
                 si.convertToString().cat(t.convertToString().getByteList());
             }
             re = match.post_match(context);
