@@ -1,9 +1,9 @@
 /*
  ***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -35,6 +35,24 @@
  ***** END LICENSE BLOCK *****/
 package org.jruby;
 
+import jnr.constants.platform.OpenFlags;
+import jnr.posix.POSIX;
+import jnr.posix.util.Platform;
+import org.jcodings.Encoding;
+import org.jruby.anno.JRubyClass;
+import org.jruby.anno.JRubyMethod;
+import org.jruby.exceptions.RaiseException;
+import org.jruby.runtime.*;
+import org.jruby.runtime.JavaSites.FileSites;
+import org.jruby.runtime.builtin.IRubyObject;
+import org.jruby.runtime.encoding.EncodingCapable;
+import org.jruby.runtime.encoding.EncodingService;
+import org.jruby.util.*;
+import org.jruby.util.io.EncodingUtils;
+import org.jruby.util.io.IOEncodable;
+import org.jruby.util.io.OpenFile;
+import org.jruby.util.io.PosixShim;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
@@ -58,32 +76,7 @@ import java.util.regex.Pattern;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipFile;
 
-import jnr.constants.platform.OpenFlags;
-import jnr.posix.POSIX;
-import jnr.posix.util.Platform;
-import org.jcodings.Encoding;
-import org.jruby.anno.JRubyClass;
-import org.jruby.anno.JRubyMethod;
-import org.jruby.runtime.Block;
-import org.jruby.runtime.ClassIndex;
-import org.jruby.runtime.JavaSites.FileSites;
-import org.jruby.runtime.ObjectAllocator;
-import org.jruby.runtime.ThreadContext;
-import static org.jruby.runtime.Visibility.*;
-import org.jruby.runtime.builtin.IRubyObject;
-import org.jruby.runtime.encoding.EncodingCapable;
-import org.jruby.util.ByteList;
-import org.jruby.util.FileResource;
-import org.jruby.util.JRubyFile;
-import org.jruby.util.StringSupport;
-import org.jruby.util.TypeConverter;
-import org.jruby.util.io.EncodingUtils;
-import org.jruby.util.io.IOEncodable;
-import org.jruby.util.io.OpenFile;
-import org.jruby.runtime.Helpers;
-import org.jruby.runtime.encoding.EncodingService;
-import org.jruby.util.io.PosixShim;
-
+import static org.jruby.runtime.Visibility.PRIVATE;
 import static org.jruby.util.io.EncodingUtils.vmode;
 import static org.jruby.util.io.EncodingUtils.vperm;
 
@@ -445,7 +438,7 @@ public class RubyFile extends RubyIO implements EncodingCapable {
     @JRubyMethod
     public IRubyObject mtime(ThreadContext context) {
         checkClosed(context);
-        return context.runtime.newFileStat(getPath(), false).mtime();
+        return ((RubyFileStat) stat(context)).mtime();
     }
 
     @JRubyMethod(meta = true)
@@ -1150,12 +1143,12 @@ public class RubyFile extends RubyIO implements EncodingCapable {
     @JRubyMethod(required = 2, rest = true, meta = true)
     public static IRubyObject utime(ThreadContext context, IRubyObject recv, IRubyObject[] args) {
         Ruby runtime = context.runtime;
-        long[] atimeval = null;
-        long[] mtimeval = null;
+        long[] atimespec = null;
+        long[] mtimespec = null;
 
-        if (args[0] != runtime.getNil() || args[1] != runtime.getNil()) {
-            atimeval = extractTimeval(context, args[0]);
-            mtimeval = extractTimeval(context, args[1]);
+        if (args[0] != context.nil || args[1] != context.nil) {
+            atimespec = extractTimespec(context, args[0]);
+            mtimespec = extractTimespec(context, args[1]);
         }
 
         for (int i = 2, j = args.length; i < j; i++) {
@@ -1167,7 +1160,19 @@ public class RubyFile extends RubyIO implements EncodingCapable {
                 throw runtime.newErrnoENOENTError(filename.toString());
             }
 
-            int result = runtime.getPosix().utimes(fileToTouch.getAbsolutePath(), atimeval, mtimeval);
+            int result;
+
+            try {
+                result = runtime.getPosix().utimensat(0, fileToTouch.getAbsolutePath(), atimespec, mtimespec, 0);
+            } catch (RaiseException re) {
+                if (re.getException().getMetaClass() == runtime.getNotImplementedError()) {
+                    // fall back on utimes
+                    result = runtime.getPosix().utimes(fileToTouch.getAbsolutePath(), atimespec, mtimespec);
+                } else {
+                    throw re;
+                }
+            }
+
             if (result == -1) {
                 throw runtime.newErrnoFromInt(runtime.getPosix().errno());
             }
@@ -1554,19 +1559,19 @@ public class RubyFile extends RubyIO implements EncodingCapable {
     }
 
     /**
-     * Extract a timeval (an array of 2 longs: seconds and microseconds from epoch) from
+     * Extract a timespec (an array of 2 longs: seconds and nanoseconds from epoch) from
      * an IRubyObject.
      */
-    private static long[] extractTimeval(ThreadContext context, IRubyObject value) {
-        long[] timeval = new long[2];
+    private static long[] extractTimespec(ThreadContext context, IRubyObject value) {
+        long[] timespec = new long[2];
 
         if (value instanceof RubyFloat) {
-            timeval[0] = Platform.IS_32_BIT ? RubyNumeric.num2int(value) : RubyNumeric.num2long(value);
+            timespec[0] = Platform.IS_32_BIT ? RubyNumeric.num2int(value) : RubyNumeric.num2long(value);
             double fraction = ((RubyFloat) value).getDoubleValue() % 1.0;
-            timeval[1] = (long)(fraction * 1e6 + 0.5);
+            timespec[1] = (long)(fraction * 1e9 + 0.5);
         } else if (value instanceof RubyNumeric) {
-            timeval[0] = Platform.IS_32_BIT ? RubyNumeric.num2int(value) : RubyNumeric.num2long(value);
-            timeval[1] = 0;
+            timespec[0] = Platform.IS_32_BIT ? RubyNumeric.num2int(value) : RubyNumeric.num2long(value);
+            timespec[1] = 0;
         } else {
             RubyTime time;
             if (value instanceof RubyTime) {
@@ -1574,11 +1579,11 @@ public class RubyFile extends RubyIO implements EncodingCapable {
             } else {
                 time = (RubyTime) TypeConverter.convertToType(context, value, context.runtime.getTime(), sites(context).to_time_checked, true);
             }
-            timeval[0] = Platform.IS_32_BIT ? RubyNumeric.num2int(time.to_i()) : RubyNumeric.num2long(time.to_i());
-            timeval[1] = Platform.IS_32_BIT ? RubyNumeric.num2int(time.usec()) : RubyNumeric.num2long(time.usec());
+            timespec[0] = Platform.IS_32_BIT ? RubyNumeric.num2int(time.to_i()) : RubyNumeric.num2long(time.to_i());
+            timespec[1] = Platform.IS_32_BIT ? RubyNumeric.num2int(time.nsec()) : RubyNumeric.num2long(time.nsec());
         }
 
-        return timeval;
+        return timespec;
     }
 
     private void checkClosed(ThreadContext context) {
