@@ -1,9 +1,9 @@
 /*
  ***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -411,7 +411,7 @@ public class RubyFloat extends RubyNumeric {
                 mod += y;
             }
             final Ruby runtime = getRuntime();
-            IRubyObject car = dbl2num(runtime, div);
+            IRubyObject car = dbl2ival(runtime, div);
             RubyFloat cdr = RubyFloat.newFloat(runtime, mod);
             return RubyArray.newArray(runtime, car, cdr);
         default:
@@ -717,7 +717,7 @@ public class RubyFloat extends RubyNumeric {
         if (f > 0.0) f = Math.floor(f);
         if (f < 0.0) f = Math.ceil(f);
 
-        return dbl2num(getRuntime(), f);
+        return dbl2ival(getRuntime(), f);
     }
 
     /** flo_numerator
@@ -756,7 +756,7 @@ public class RubyFloat extends RubyNumeric {
 
         Ruby runtime = context.runtime;
 
-        IRubyObject rf = RubyNumeric.dbl2num(runtime, f);
+        IRubyObject rf = RubyNumeric.dbl2ival(runtime, f);
         IRubyObject rn = RubyFixnum.newFixnum(runtime, n);
         return f_mul(context, rf, f_expt(context, RubyFixnum.newFixnum(runtime, FLT_RADIX), rn));
     }
@@ -786,7 +786,7 @@ public class RubyFloat extends RubyNumeric {
             long n = exp[0] - DBL_MANT_DIG;
 
 
-            IRubyObject rf = RubyNumeric.dbl2num(runtime, f);
+            IRubyObject rf = RubyNumeric.dbl2ival(runtime, f);
             IRubyObject rn = RubyFixnum.newFixnum(runtime, n);
 
             if (f_zero_p(context, rf) || !(f_negative_p(context, rn) || f_zero_p(context, rn)))
@@ -817,7 +817,7 @@ public class RubyFloat extends RubyNumeric {
     @JRubyMethod(name = "floor")
     @Override
     public IRubyObject floor() {
-        return dbl2num(getRuntime(), Math.floor(value));
+        return dbl2ival(getRuntime(), Math.floor(value));
     }
 
     /** flo_ceil
@@ -826,7 +826,7 @@ public class RubyFloat extends RubyNumeric {
     @JRubyMethod(name = "ceil")
     @Override
     public IRubyObject ceil() {
-        return dbl2num(getRuntime(), Math.ceil(value));
+        return dbl2ival(getRuntime(), Math.ceil(value));
     }
 
     /** flo_round
@@ -834,7 +834,7 @@ public class RubyFloat extends RubyNumeric {
      */
     @Override
     public IRubyObject round() {
-        return dbl2num(getRuntime(), val2dbl());
+        return dbl2ival(getRuntime(), val2dbl());
     }
 
     @JRubyMethod(name = "round", optional = 1)
@@ -869,7 +869,7 @@ public class RubyFloat extends RubyNumeric {
             return RubyFloat.newFloat(context.runtime, number);
         }
         if (digits < -(binexp > 0 ? binexp / 3 + 1 : binexp / 4)) {
-            return dbl2num(context.runtime, (long) 0);
+            return dbl2ival(context.runtime, (long) 0);
         }
 
         if (Double.isInfinite(magnifier)) {
@@ -898,7 +898,7 @@ public class RubyFloat extends RubyNumeric {
                 BigDecimal roundedNumber = new BigDecimal(Double.toString(number));
                 return RubyBignum.newBignum(context.runtime, roundedNumber.toBigInteger());
             }
-            return dbl2num(context.runtime, (long)number);
+            return dbl2ival(context.runtime, (long)number);
         }
     }
 
