@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -180,9 +180,14 @@ public class RubyInstanceConfig {
     public void processArgumentsWithRubyopts() {
         // environment defaults to System.getenv normally
         Object rubyoptObj = environment.get("RUBYOPT");
-        String rubyopt = rubyoptObj == null ? null : rubyoptObj.toString();
 
-        if (rubyopt == null || rubyopt.length() == 0) return;
+        if (rubyoptObj == null) return;
+
+        // Our argument processor bails if an arg starts with space, so we trim the RUBYOPT line
+        // See #4849
+        String rubyopt = rubyoptObj.toString().trim();
+
+        if (rubyopt.length() == 0) return;
 
         String[] rubyoptArgs = rubyopt.split("\\s+");
         if (rubyoptArgs.length != 0) {
@@ -1439,15 +1444,6 @@ public class RubyInstanceConfig {
         return kernelGsubDefined;
     }
 
-    /**
-     * get whether IPv4 is preferred
-     *
-     * @see Options#PREFER_IPV4
-     */
-    public boolean getIPv4Preferred() {
-        return preferIPv4;
-    }
-
     /**
      * get whether uppercase package names will be honored
      */
@@ -1587,7 +1583,6 @@ public class RubyInstanceConfig {
     private boolean updateNativeENVEnabled = true;
     private boolean kernelGsubDefined;
     private boolean hasScriptArgv = false;
-    private boolean preferIPv4 = Options.PREFER_IPV4.load();
     private boolean frozenStringLiteral = false;
     private boolean debuggingFrozenStringLiteral = false;
     private String jrubyHome;
@@ -1898,14 +1893,12 @@ public class RubyInstanceConfig {
     private static int initGlobalJavaVersion() {
         final String specVersion = Options.BYTECODE_VERSION.load();
         switch ( specVersion ) {
-            case "1.6" : return Opcodes.V1_6; // 50
+            case "1.6" :
+                throw new UnsupportedClassVersionError("JRuby requires Java 7 or higher");
             case "1.7" : return Opcodes.V1_7; // 51
             case "1.8" : case "8" : return Opcodes.V1_8; // 52
-            // NOTE: JDK 9 now returns "9" instead of "1.9"
-            case "1.9" : case "9" : return Opcodes.V1_8 + 1; // 53
             default :
-                System.err.println("unsupported Java version \"" + specVersion + "\", defaulting to 1.7");
-                return Opcodes.V1_7;
+                return Opcodes.V9;
         }
     }
 
@@ -2034,4 +2027,9 @@ public class RubyInstanceConfig {
     }
 
     @Deprecated public static final String JIT_CODE_CACHE = "";
+
+    @Deprecated
+    public boolean getIPv4Preferred() {
+        return Options.PREFER_IPV4.load();
+    }
 }
