@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -47,6 +47,7 @@ import org.joni.Option;
 import org.joni.Regex;
 import org.joni.Region;
 import org.joni.Syntax;
+import org.joni.WarnCallback;
 import org.joni.exception.JOniException;
 import org.jruby.anno.JRubyClass;
 import org.jruby.anno.JRubyMethod;
@@ -146,7 +147,7 @@ public class RubyRegexp extends RubyObject implements ReOptions, EncodingCapable
     private static Regex makeRegexp(Ruby runtime, ByteList bytes, RegexpOptions options, Encoding enc) {
         try {
             int p = bytes.getBegin();
-            return new Regex(bytes.getUnsafeBytes(), p, p + bytes.getRealSize(), options.toJoniOptions(), enc, Syntax.DEFAULT, runtime.getWarnings());
+            return new Regex(bytes.getUnsafeBytes(), p, p + bytes.getRealSize(), options.toJoniOptions(), enc, Syntax.DEFAULT, runtime.getRegexpWarnings());
         } catch (Exception e) {
             RegexpSupport.raiseRegexpError19(runtime, bytes, enc, options, e.getMessage());
             return null; // not reached
@@ -426,21 +427,26 @@ public class RubyRegexp extends RubyObject implements ReOptions, EncodingCapable
                 pattern.getEncoding() + " regexp with " + strEnc + " string)");
     }
 
-    private Encoding checkEncoding(RubyString str, boolean warn) {
-        if (str.scanForCodeRange() == StringSupport.CR_BROKEN) {
-            throw getRuntime().newArgumentError("invalid byte sequence in " + str.getEncoding());
+    private Encoding prepareEncoding(RubyString str, boolean warn) {
+        Encoding enc = str.getEncoding();
+        int cr = str.scanForCodeRange();
+        if (cr == StringSupport.CR_BROKEN) {
+            throw getRuntime().newArgumentError("invalid byte sequence in " + enc);
         }
         check();
-        Encoding enc = str.getEncoding();
-        if (!enc.isAsciiCompatible()) {
-            if (enc != pattern.getEncoding()) encodingMatchError(getRuntime(), pattern, enc);
+        Encoding patternEnc = pattern.getEncoding();
+        if (patternEnc == enc) {
+        } else if (cr == StringSupport.CR_7BIT && patternEnc == USASCIIEncoding.INSTANCE) {
+            enc = patternEnc;
+        } else if (!enc.isAsciiCompatible()) {
+            encodingMatchError(getRuntime(), pattern, enc);
         } else if (options.isFixed()) {
-            if (enc != pattern.getEncoding() &&
-               (!pattern.getEncoding().isAsciiCompatible() ||
-               str.scanForCodeRange() != StringSupport.CR_7BIT)) encodingMatchError(getRuntime(), pattern, enc);
-            enc = pattern.getEncoding();
+            if (enc != patternEnc &&
+               (!patternEnc.isAsciiCompatible() ||
+               cr != StringSupport.CR_7BIT)) encodingMatchError(getRuntime(), pattern, enc);
+            enc = patternEnc;
         }
-        if (warn && isEncodingNone() && enc != ASCIIEncoding.INSTANCE && str.scanForCodeRange() != StringSupport.CR_7BIT) {
+        if (warn && isEncodingNone() && enc != ASCIIEncoding.INSTANCE && cr != StringSupport.CR_7BIT) {
             getRuntime().getWarnings().warn(ID.REGEXP_MATCH_AGAINST_STRING, "regexp match /.../n against to " + enc + " string");
         }
         return enc;
@@ -448,7 +454,7 @@ public class RubyRegexp extends RubyObject implements ReOptions, EncodingCapable
 
     public final Regex preparePattern(RubyString str) {
         // checkEncoding does `check();` no need to here
-        Encoding enc = checkEncoding(str, true);
+        Encoding enc = prepareEncoding(str, true);
         if (enc == pattern.getEncoding()) return pattern;
         return getPreprocessedRegexpFromCache(getRuntime(), this.str, enc, options, RegexpSupport.ErrorMode.PREPROCESS);
     }
@@ -662,6 +668,10 @@ public class RubyRegexp extends RubyObject implements ReOptions, EncodingCapable
                     c = bytes[p] & 0xff;
                 } else {
                     cl = StringSupport.preciseLength(enc, bytes, p, end);
+                    if (cl < 0) {
+                        p += StringSupport.length(enc, bytes, p, end);
+                        continue;
+                    }
                     c = enc.mbcToCode(bytes, p, end);
                 }
 
@@ -940,8 +950,8 @@ public class RubyRegexp extends RubyObject implements ReOptions, EncodingCapable
 
         if (!arg2.isNil()) {
             ByteList kcodeBytes = arg2.convertToString().getByteList();
-            if ((kcodeBytes.getRealSize() > 0 && kcodeBytes.getUnsafeBytes()[kcodeBytes.getBegin()] == 'n') ||
-                (kcodeBytes.getRealSize() > 1 && kcodeBytes.getUnsafeBytes()[kcodeBytes.getBegin() + 1] == 'N')) {
+            if (kcodeBytes.getRealSize() > 0 && (kcodeBytes.get(0) == 'n' || kcodeBytes.get(0) == 'N')) {
+                newOptions.setEncodingNone(true);
                 return regexpInitialize(arg0.convertToString().getByteList(), ASCIIEncoding.INSTANCE, newOptions);
             } else {
                 getRuntime().getWarnings().warn("encoding option is ignored - " + kcodeBytes);
@@ -1385,7 +1395,7 @@ public class RubyRegexp extends RubyObject implements ReOptions, EncodingCapable
 
                 if (bytes[p] == ':' && bytes[p + len - 1] == ')') {
                     try {
-                        new Regex(bytes, ++p, p + (len -= 2), Option.DEFAULT, str.getEncoding(), Syntax.DEFAULT);
+                        new Regex(bytes, ++p, p + (len -= 2), Option.DEFAULT, str.getEncoding(), Syntax.DEFAULT, WarnCallback.NONE);
                         err = false;
                     } catch (JOniException e) {
                         err = true;
