@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -97,11 +97,22 @@ public class RubySignal {
     @JRubyMethod(meta = true)
     public static IRubyObject list(ThreadContext context, IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
-        RubyHash names = RubyHash.newHash(runtime);
-        for (Map.Entry<String, Integer> sig : RubySignal.list().entrySet()) {
-            names.op_aset(context, runtime.newString(sig.getKey()), runtime.newFixnum(sig.getValue()));
+        RubyHash names;
+
+        synchronized (recv) {
+            names = (RubyHash) recv.getInternalVariables().getInternalVariable("signal_list");
+            if (names == null) {
+                names = RubyHash.newHash(runtime);
+                for (Map.Entry<String, Integer> sig : RubySignal.list().entrySet()) {
+                    names.op_aset(context, runtime.freezeAndDedupString(runtime.newString(sig.getKey())), runtime.newFixnum(sig.getValue()));
+                }
+                names.op_aset(context, runtime.freezeAndDedupString(runtime.newString("EXIT")), runtime.newFixnum(0));
+                recv.getInternalVariables().setInternalVariable("signal_list", names);
+            } else {
+                names.dup(context);
+            }
         }
-        names.op_aset(context, runtime.newString("EXIT"), runtime.newFixnum(0));
+        
         return names;
     }
 
