@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -62,12 +62,14 @@ import org.jruby.anno.JRubyClass;
 import org.jruby.anno.JRubyMethod;
 import org.jruby.exceptions.RaiseException;
 import org.jruby.exceptions.ThreadKill;
+import org.jruby.exceptions.Unrescuable;
 import org.jruby.internal.runtime.NativeThread;
 import org.jruby.internal.runtime.RubyRunnable;
 import org.jruby.internal.runtime.ThreadLike;
 import org.jruby.internal.runtime.ThreadService;
 import org.jruby.java.proxies.ConcreteJavaProxy;
 import org.jruby.javasupport.JavaUtil;
+import org.jruby.runtime.Arity;
 import org.jruby.runtime.Block;
 import org.jruby.runtime.ClassIndex;
 import org.jruby.runtime.Helpers;
@@ -81,6 +83,7 @@ import org.jruby.util.ByteList;
 import org.jruby.util.StringSupport;
 import org.jruby.util.TypeConverter;
 import org.jruby.util.io.BlockingIO;
+import org.jruby.util.io.ChannelFD;
 import org.jruby.util.io.OpenFile;
 import org.jruby.util.log.Logger;
 import org.jruby.util.log.LoggerFactory;
@@ -131,7 +134,7 @@ public class RubyThread extends RubyObject implements ExecutionContext {
      * it here to continue propagating it while handling thread shutdown
      * logic and abort_on_exception.
      */
-    private volatile RaiseException exitingException;
+    private volatile Throwable exitingException;
 
     /** The ThreadGroup to which this thread belongs */
     private volatile RubyThreadGroup threadGroup;
@@ -276,6 +279,7 @@ public class RubyThread extends RubyObject implements ExecutionContext {
 
     private void toKill() {
         pendingInterruptClear();
+        status.set(Status.ABORTING);
         throwThreadKill();
     }
 
@@ -646,20 +650,8 @@ public class RubyThread extends RubyObject implements ExecutionContext {
         catch (SecurityException ignore) { } // current thread can not modify
     }
 
-    // TODO likely makes sense to have a counter or the Ruby class directly (could be included with JMX)
-    private static final WeakHashMap<Ruby, AtomicLong> threadCount = new WeakHashMap<Ruby, AtomicLong>(4);
-
     private static long incAndGetThreadCount(final Ruby runtime) {
-        AtomicLong counter = threadCount.get(runtime);
-        if ( counter == null ) {
-            synchronized (runtime) {
-                counter = threadCount.get(runtime);
-                if ( counter == null ) {
-                    threadCount.put(runtime, counter = new AtomicLong(0));
-                }
-            }
-        }
-        return counter.incrementAndGet();
+        return runtime.getThreadService().incrementAndGetThreadCount();
     }
 
     private static RubyThread startThread(final IRubyObject recv, final IRubyObject[] args, boolean callInit, Block block) {
@@ -917,7 +909,7 @@ public class RubyThread extends RubyObject implements ExecutionContext {
     }
 
     public boolean isAlive(){
-        return threadImpl.isAlive() && status.get() != Status.ABORTING;
+        return threadImpl.isAlive();
     }
 
     @JRubyMethod(name = "[]", required = 1)
@@ -1069,10 +1061,14 @@ public class RubyThread extends RubyObject implements ExecutionContext {
         }
 
         if (exitingException != null) {
-            // Set $! in the current thread before exiting
-            runtime.getGlobalVariables().set("$!", (IRubyObject)exitingException.getException());
-            throw exitingException;
-
+            if (exitingException instanceof RaiseException) {
+                RaiseException raiseException = (RaiseException) exitingException;
+                // Set $! in the current thread before exiting
+                runtime.getGlobalVariables().set("$!", (IRubyObject) raiseException.getException());
+            } else {
+                runtime.getGlobalVariables().set("$!", JavaUtil.convertJavaToUsableRubyObject(runtime, exitingException));
+            }
+            Helpers.throwException(exitingException);
         }
 
         // check events before leaving
@@ -1496,7 +1492,9 @@ public class RubyThread extends RubyObject implements ExecutionContext {
     }
 
     public void exitSleep() {
-        status.set(Status.RUN);
+        if (status.get() != Status.ABORTING) {
+            status.set(Status.RUN);
+        }
     }
 
     @JRubyMethod(name = {"kill", "exit", "terminate"})
@@ -1545,51 +1543,66 @@ public class RubyThread extends RubyObject implements ExecutionContext {
         throw getRuntime().newNotImplementedError("Thread-specific SAFE levels are not supported");
     }
 
+    @JRubyMethod(name = "backtrace")
     public IRubyObject backtrace(ThreadContext context) {
-        return backtrace20(context, NULL_ARRAY);
+        return backtraceInternal(context, null, null);
     }
 
-    @JRubyMethod(name = "backtrace", optional = 2)
-    public IRubyObject backtrace20(ThreadContext context, IRubyObject[] args) {
+    @JRubyMethod(name = "backtrace")
+    public IRubyObject backtrace(ThreadContext context, IRubyObject level) {
+        return backtraceInternal(context, level, null);
+    }
+
+    @JRubyMethod(name = "backtrace")
+    public IRubyObject backtrace(ThreadContext context, IRubyObject level, IRubyObject length) {
+        return backtraceInternal(context, level, length);
+    }
+
+    private IRubyObject backtraceInternal(ThreadContext context, IRubyObject level, IRubyObject length) {
         ThreadContext myContext = getContext();
+        Thread nativeThread = getNativeThread();
 
         // context can be nil if we have not started or GC has claimed our context
-        if (myContext == null) return context.nil;
-
-        Thread nativeThread = getNativeThread();
-
         // nativeThread can be null if the thread has terminated and GC has claimed it
-        if (nativeThread == null) return context.nil;
-
         // nativeThread may have finished
-        if (!nativeThread.isAlive()) return context.nil;
+        if (myContext == null || nativeThread == null || !nativeThread.isAlive()) return context.nil;
 
         Ruby runtime = context.runtime;
-        Integer[] ll = RubyKernel.levelAndLengthFromArgs(runtime, args, 0);
-        Integer level = ll[0], length = ll[1];
+        Integer[] ll = RubyKernel.levelAndLengthFromArgs(runtime, level, length, 0);
+        Integer levelInt = ll[0], lengthInt = ll[1];
 
-        return myContext.createCallerBacktrace(level, length, getNativeThread().getStackTrace());
+        return myContext.createCallerBacktrace(levelInt, lengthInt, getNativeThread().getStackTrace());
     }
 
-    @JRubyMethod(optional = 2)
-    public IRubyObject backtrace_locations(ThreadContext context, IRubyObject[] args) {
+    @JRubyMethod
+    public IRubyObject backtrace_locations(ThreadContext context) {
+        return backtraceLocationsInternal(context, null, null);
+    }
+
+    @JRubyMethod
+    public IRubyObject backtrace_locations(ThreadContext context, IRubyObject level) {
+        return backtraceLocationsInternal(context, level, null);
+    }
+
+    @JRubyMethod
+    public IRubyObject backtrace_locations(ThreadContext context, IRubyObject level, IRubyObject length) {
+        return backtraceLocationsInternal(context, level, length);
+    }
+
+    private IRubyObject backtraceLocationsInternal(ThreadContext context, IRubyObject level, IRubyObject length) {
         ThreadContext myContext = getContext();
-
-        if (myContext == null) return context.nil;
-
         Thread nativeThread = getNativeThread();
 
+        // context can be nil if we have not started or GC has claimed our context
         // nativeThread can be null if the thread has terminated and GC has claimed it
-        if (nativeThread == null) return context.nil;
-
         // nativeThread may have finished
-        if (!nativeThread.isAlive()) return context.nil;
+        if (myContext == null || nativeThread == null || !nativeThread.isAlive()) return context.nil;
 
         Ruby runtime = context.runtime;
-        Integer[] ll = RubyKernel.levelAndLengthFromArgs(runtime, args, 0);
-        Integer level = ll[0], length = ll[1];
+        Integer[] ll = RubyKernel.levelAndLengthFromArgs(runtime, level, length, 0);
+        Integer levelInt = ll[0], lengthInt = ll[1];
 
-        return myContext.createCallerLocations(level, length, getNativeThread().getStackTrace());
+        return myContext.createCallerLocations(levelInt, lengthInt, getNativeThread().getStackTrace());
     }
 
     public StackTraceElement[] javaBacktrace() {
@@ -1606,44 +1619,41 @@ public class RubyThread extends RubyObject implements ExecutionContext {
     }
 
     public void exceptionRaised(RaiseException exception) {
-        assert isCurrent();
-
-        RubyException rubyException = exception.getException();
-        Ruby runtime = rubyException.getRuntime();
-        if (runtime.getSystemExit().isInstance(rubyException)) {
-            runtime.getThreadService().getMainThread().raise(rubyException);
-        }
-        else if (abortOnException(runtime)) {
-            runtime.getThreadService().getMainThread().raise(rubyException);
-            return;
-        }
-        else if (runtime.isDebug()) {
-            runtime.printError(exception.getException());
-        }
-        exitingException = exception;
+        exceptionRaised((Throwable) exception);
     }
 
     /**
-     * For handling all non-Ruby exceptions bubbling out of threads
-     * @param exception
+     * For handling all exceptions bubbling out of threads
+     * @param throwable
      */
-    @SuppressWarnings("deprecation")
-    public void exceptionRaised(Throwable exception) {
-        if (exception instanceof RaiseException) {
-            exceptionRaised((RaiseException)exception);
-            return;
+    public void exceptionRaised(Throwable throwable) {
+        // if unrescuable (internal exceptions) just re-raise and let it be handled by thread handler
+        if (throwable instanceof Unrescuable) {
+            Helpers.throwException(throwable);
         }
 
+        Ruby runtime = getRuntime();
+
         assert isCurrent();
 
-        Ruby runtime = getRuntime();
-        if (abortOnException(runtime) && exception instanceof Error) {
-            // re-propagate on main thread
-            runtime.getThreadService().getMainThread().raise(JavaUtil.convertJavaToUsableRubyObject(runtime, exception));
+        IRubyObject rubyException;
+
+        if (throwable instanceof RaiseException) {
+            RaiseException exception = (RaiseException) throwable;
+            rubyException = exception.getException();
         } else {
-            // just rethrow on this thread, let system handlers report it
-            Helpers.throwException(exception);
+            rubyException = JavaUtil.convertJavaToUsableRubyObject(runtime, throwable);
         }
+
+        if (runtime.getSystemExit().isInstance(rubyException)) {
+            runtime.getThreadService().getMainThread().raise(rubyException);
+        } else if (abortOnException(runtime)) {
+            runtime.getThreadService().getMainThread().raise(rubyException);
+        } else if (runtime.isDebug()) {
+            runtime.printError(throwable);
+        }
+
+        exitingException = throwable;
     }
 
     private boolean abortOnException(Ruby runtime) {
@@ -1747,75 +1757,90 @@ public class RubyThread extends RubyObject implements ExecutionContext {
      */
     public boolean select(Channel channel, OpenFile fptr, int ops, long timeout) {
         // Use selectables but only if they're not associated with a file (which has odd select semantics)
-        if (channel instanceof SelectableChannel && (fptr == null || !fptr.fd().isNativeFile)) {
+        ChannelFD fd = fptr == null ? null : fptr.fd();
+        if (channel instanceof SelectableChannel && fd != null) {
             SelectableChannel selectable = (SelectableChannel)channel;
 
-            synchronized (selectable.blockingLock()) {
-                boolean oldBlocking = selectable.isBlocking();
+            // ensure we have fptr locked, but release it to avoid deadlock
+            boolean locked = false;
+            if (fptr != null) {
+                locked = fptr.lock();
+                fptr.unlock();
+            }
+            try {
+                synchronized (selectable.blockingLock()) {
+                    boolean oldBlocking = selectable.isBlocking();
 
-                SelectionKey key;
-                try {
-                    selectable.configureBlocking(false);
-
-                    if (fptr != null) fptr.addBlockingThread(this);
-                    currentSelector = getRuntime().getSelectorPool().get(selectable.provider());
-
-                    key = selectable.register(currentSelector, ops);
-
-                    beforeBlockingCall();
-                    int result;
-                    if (timeout < 0) {
-                        result = currentSelector.select();
-                    } else if (timeout == 0) {
-                        result = currentSelector.selectNow();
-                    } else {
-                        result = currentSelector.select(timeout);
-                    }
-
-                    // check for thread events, in case we've been woken up to die
-                    pollThreadEvents();
-
-                    if (result == 1) {
-                        Set<SelectionKey> keySet = currentSelector.selectedKeys();
-
-                        if (keySet.iterator().next() == key) {
-                            return true;
-                        }
-                    }
-
-                    return false;
-                } catch (IOException ioe) {
-                    throw getRuntime().newIOErrorFromException(ioe);
-                } finally {
-                    // Note: I don't like ignoring these exceptions, but it's
-                    // unclear how likely they are to happen or what damage we
-                    // might do by ignoring them. Note that the pieces are separate
-                    // so that we can ensure one failing does not affect the others
-                    // running.
-
-                    // shut down and null out the selector
+                    SelectionKey key;
                     try {
-                        if (currentSelector != null) {
-                            getRuntime().getSelectorPool().put(currentSelector);
+                        selectable.configureBlocking(false);
+
+                        if (fptr != null) fptr.addBlockingThread(this);
+                        currentSelector = getRuntime().getSelectorPool().get(selectable.provider());
+
+                        key = selectable.register(currentSelector, ops);
+
+                        beforeBlockingCall();
+                        int result;
+
+                        if (timeout < 0) {
+                            result = currentSelector.select();
+                        } else if (timeout == 0) {
+                            result = currentSelector.selectNow();
+                        } else {
+                            result = currentSelector.select(timeout);
                         }
-                    } catch (Exception e) {
-                        // ignore
+
+                        // check for thread events, in case we've been woken up to die
+                        pollThreadEvents();
+
+                        if (result == 1) {
+                            Set<SelectionKey> keySet = currentSelector.selectedKeys();
+
+                            if (keySet.iterator().next() == key) {
+                                return true;
+                            }
+                        }
+
+                        return false;
+                    } catch (IOException ioe) {
+                        throw getRuntime().newIOErrorFromException(ioe);
                     } finally {
-                        currentSelector = null;
+                        // Note: I don't like ignoring these exceptions, but it's
+                        // unclear how likely they are to happen or what damage we
+                        // might do by ignoring them. Note that the pieces are separate
+                        // so that we can ensure one failing does not affect the others
+                        // running.
+
+                        // shut down and null out the selector
+                        try {
+                            if (currentSelector != null) {
+                                getRuntime().getSelectorPool().put(currentSelector);
+                            }
+                        } catch (Exception e) {
+                            // ignore
+                        } finally {
+                            currentSelector = null;
+                        }
+
+                        // remove this thread as a blocker against the given IO
+                        if (fptr != null) fptr.removeBlockingThread(this);
+
+                        // go back to previous blocking state on the selectable
+                        try {
+                            selectable.configureBlocking(oldBlocking);
+                        } catch (Exception e) {
+                            // ignore
+                        }
+
+                        // clear thread state from blocking call
+                        afterBlockingCall();
                     }
-
-                    // remove this thread as a blocker against the given IO
-                    if (fptr != null) fptr.removeBlockingThread(this);
-
-                    // go back to previous blocking state on the selectable
-                    try {
-                        selectable.configureBlocking(oldBlocking);
-                    } catch (Exception e) {
-                        // ignore
-                    }
-
-                    // clear thread state from blocking call
-                    afterBlockingCall();
+                }
+            } finally {
+                if (fptr != null) {
+                    fptr.lock();
+                    if (locked) fptr.unlock();
                 }
             }
         } else {
@@ -2054,4 +2079,39 @@ public class RubyThread extends RubyObject implements ExecutionContext {
             ts.setCritical(critical);
         }
     }
+
+    @Deprecated
+    public IRubyObject backtrace20(ThreadContext context, IRubyObject[] args) {
+        return backtrace(context);
+    }
+
+    @Deprecated
+    public IRubyObject backtrace(ThreadContext context, IRubyObject[] args) {
+        switch (args.length) {
+            case 0:
+                return backtrace(context);
+            case 1:
+                return backtrace(context, args[0]);
+            case 2:
+                return backtrace(context, args[0], args[1]);
+            default:
+                Arity.checkArgumentCount(context.runtime, args, 0, 2);
+                return null; // not reached
+        }
+    }
+
+    @Deprecated
+    public IRubyObject backtrace_locations(ThreadContext context, IRubyObject[] args) {
+        switch (args.length) {
+            case 0:
+                return backtrace_locations(context);
+            case 1:
+                return backtrace_locations(context, args[0]);
+            case 2:
+                return backtrace_locations(context, args[0], args[1]);
+            default:
+                Arity.checkArgumentCount(context.runtime, args, 0, 2);
+                return null; // not reached
+        }
+    }
 }
