@@ -12,7 +12,7 @@ public class KeywordRestArgNode extends ArgumentNode {
     }
     
     @Override
-    public Object accept(NodeVisitor visitor) {
+    public <T> T accept(NodeVisitor<T> visitor) {
         return visitor.visitKeywordRestArgNode(this);
     }
     
