@@ -1,6 +1,11 @@
 package org.jruby.ext.etc;
 
+import java.net.InetAddress;
+import java.net.UnknownHostException;
 import java.util.concurrent.atomic.AtomicBoolean;
+
+import org.jruby.RubyArray;
+import org.jruby.RubyHash;
 import org.jruby.anno.JRubyMethod;
 import org.jruby.anno.JRubyModule;
 import org.jruby.common.IRubyWarnings.ID;
@@ -9,8 +14,8 @@ import jnr.posix.Passwd;
 import jnr.posix.Group;
 import jnr.posix.POSIX;
 import jnr.posix.util.Platform;
-import org.jruby.CompatVersion;
 import org.jruby.Ruby;
+import org.jruby.RubyFixnum;
 import org.jruby.RubyModule;
 import org.jruby.RubyNumeric;
 import org.jruby.RubyString;
@@ -20,7 +25,7 @@ import org.jruby.runtime.Block;
 import org.jruby.runtime.ThreadContext;
 import org.jruby.runtime.builtin.IRubyObject;
 import org.jruby.util.ByteList;
-import org.jruby.util.NormalizedFile;
+import org.jruby.util.SafePropertyAccessor;
 
 @JRubyModule(name="Etc")
 public class RubyEtc {
@@ -53,9 +58,7 @@ public class RubyEtc {
         };
         
         runtime.setPasswdStruct(RubyStruct.newInstance(runtime.getStructClass(), args, Block.NULL_BLOCK));
-        if (runtime.is1_9()) {
-            runtime.getEtc().defineConstant("Passwd", runtime.getPasswdStruct());
-        }
+        runtime.getEtc().defineConstant("Passwd", runtime.getPasswdStruct());
     }
 
     private static void defineGroupStruct(Ruby runtime) {
@@ -68,9 +71,7 @@ public class RubyEtc {
         };
         
         runtime.setGroupStruct(RubyStruct.newInstance(runtime.getStructClass(), args, Block.NULL_BLOCK));
-        if (runtime.is1_9()) {
-            runtime.getEtc().defineConstant("Group", runtime.getGroupStruct());
-        }
+        runtime.getEtc().defineConstant("Group", runtime.getGroupStruct());
     }
     
     private static IRubyObject setupPasswd(Ruby runtime, Passwd passwd) {
@@ -108,14 +109,15 @@ public class RubyEtc {
         for(int i = 0; i<arr.length; i++) {
             arr[i] = runtime.newString(members[i]);
         }
-        return runtime.newArrayNoCopy(arr);
+        return RubyArray.newArrayMayCopy(runtime, arr);
     }
 
 
-    @JRubyMethod(name = "getpwuid", optional=1, module = true)
-    public static IRubyObject getpwuid(IRubyObject recv, IRubyObject[] args) {
+    @JRubyMethod(optional=1, module = true)
+    public static synchronized IRubyObject getpwuid(IRubyObject recv, IRubyObject[] args) {
         Ruby runtime = recv.getRuntime();
         POSIX posix = runtime.getPosix();
+        IRubyObject oldExc = runtime.getGlobalVariables().get("$!"); // Save $!
         try {
             int uid = args.length == 0 ? posix.getuid() : RubyNumeric.fix2int(args[0]);
             Passwd pwd = posix.getpwuid(uid);
@@ -128,6 +130,7 @@ public class RubyEtc {
             return setupPasswd(runtime, pwd);
         } catch (RaiseException re) {
             if (runtime.getNotImplementedError().isInstance(re.getException())) {
+                runtime.getGlobalVariables().set("$!", oldExc); // Restore $!
                 return runtime.getNil();
             }
             throw re;
@@ -139,19 +142,21 @@ public class RubyEtc {
         }
     }
 
-    @JRubyMethod(name = "getpwnam", required=1, module = true)
-    public static IRubyObject getpwnam(IRubyObject recv, IRubyObject name) {
+    @JRubyMethod(required=1, module = true)
+    public static synchronized IRubyObject getpwnam(IRubyObject recv, IRubyObject name) {
         Ruby runtime = recv.getRuntime();
         String nam = name.convertToString().toString();
         try {
             Passwd pwd = runtime.getPosix().getpwnam(nam);
-            if(pwd == null) {
+            if (pwd == null) {
                 if (Platform.IS_WINDOWS) {  // MRI behavior
                     return runtime.getNil();
                 }
                 throw runtime.newArgumentError("can't find user for " + nam);
             }
             return setupPasswd(recv.getRuntime(), pwd);
+        } catch (RaiseException e) {
+            throw e;
         } catch (Exception e) {
             if (runtime.getDebug().isTrue()) {
                 runtime.getWarnings().warn(ID.NOT_IMPLEMENTED, "Etc.getpwnam is not supported by JRuby on this platform");
@@ -161,7 +166,7 @@ public class RubyEtc {
     }
 
     @JRubyMethod(module = true)
-    public static IRubyObject passwd(IRubyObject recv, Block block) {
+    public static synchronized IRubyObject passwd(IRubyObject recv, Block block) {
         Ruby runtime = recv.getRuntime();
         POSIX posix = runtime.getPosix();
         try {
@@ -200,8 +205,8 @@ public class RubyEtc {
         }
     }
 
-    @JRubyMethod(name = "getlogin", module = true)
-    public static IRubyObject getlogin(IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject getlogin(IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
 
         try {
@@ -222,8 +227,8 @@ public class RubyEtc {
         }
     }
 
-    @JRubyMethod(name = "endpwent", module = true)
-    public static IRubyObject endpwent(IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject endpwent(IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
         try {
             runtime.getPosix().endpwent();
@@ -235,8 +240,8 @@ public class RubyEtc {
         return runtime.getNil();
     }
 
-    @JRubyMethod(name = "setpwent", module = true)
-    public static IRubyObject setpwent(IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject setpwent(IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
         try {
             runtime.getPosix().setpwent();
@@ -248,8 +253,8 @@ public class RubyEtc {
         return runtime.getNil();
     }
 
-    @JRubyMethod(name = "getpwent", module = true)
-    public static IRubyObject getpwent(IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject getpwent(IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
         try {
             Passwd passwd = runtime.getPosix().getpwent();
@@ -266,19 +271,21 @@ public class RubyEtc {
         }
     }
 
-    @JRubyMethod(name = "getgrnam", required=1, module = true)
-    public static IRubyObject getgrnam(IRubyObject recv, IRubyObject name) {
+    @JRubyMethod(required=1, module = true)
+    public static synchronized IRubyObject getgrnam(IRubyObject recv, IRubyObject name) {
         Ruby runtime = recv.getRuntime();
         String nam = name.convertToString().toString();
         try {
             Group grp = runtime.getPosix().getgrnam(nam);
-            if(grp == null) {
+            if (grp == null) {
                 if (Platform.IS_WINDOWS) {  // MRI behavior
                     return runtime.getNil();
                 }
                 throw runtime.newArgumentError("can't find group for " + nam);
             }
             return setupGroup(runtime, grp);
+        } catch (RaiseException e) {
+            throw e;
         } catch (Exception e) {
             if (runtime.getDebug().isTrue()) {
                 runtime.getWarnings().warn(ID.NOT_IMPLEMENTED, "Etc.getgrnam is not supported by JRuby on this platform");
@@ -287,8 +294,8 @@ public class RubyEtc {
         }
     }
 
-    @JRubyMethod(name = "getgrgid", optional=1, module = true)
-    public static IRubyObject getgrgid(IRubyObject recv, IRubyObject[] args) {
+    @JRubyMethod(optional=1, module = true)
+    public static synchronized IRubyObject getgrgid(IRubyObject recv, IRubyObject[] args) {
         Ruby runtime = recv.getRuntime();
         POSIX posix = runtime.getPosix();
 
@@ -312,8 +319,8 @@ public class RubyEtc {
         }
     }
 
-    @JRubyMethod(name = "endgrent", module = true)
-    public static IRubyObject endgrent(IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject endgrent(IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
         try {
             runtime.getPosix().endgrent();
@@ -326,7 +333,7 @@ public class RubyEtc {
     }
 
     @JRubyMethod(module = true)
-    public static IRubyObject setgrent(IRubyObject recv) {
+    public static synchronized IRubyObject setgrent(IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
         try {
             runtime.getPosix().setgrent();
@@ -339,7 +346,7 @@ public class RubyEtc {
     }
 
     @JRubyMethod(module = true)
-    public static IRubyObject group(IRubyObject recv, Block block) {
+    public static synchronized IRubyObject group(IRubyObject recv, Block block) {
         Ruby runtime = recv.getRuntime();
         POSIX posix = runtime.getPosix();
 
@@ -383,8 +390,8 @@ public class RubyEtc {
         return runtime.getNil();
     }
 
-    @JRubyMethod(name = "getgrent", module = true)
-    public static IRubyObject getgrent(IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject getgrent(IRubyObject recv) {
         Ruby runtime = recv.getRuntime();
         try {
             Group gr;
@@ -408,25 +415,22 @@ public class RubyEtc {
         }
     }
     
-    @JRubyMethod(name = "systmpdir", module = true, compat = CompatVersion.RUBY1_9)
-    public static IRubyObject systmpdir(ThreadContext context, IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject systmpdir(ThreadContext context, IRubyObject recv) {
         Ruby runtime = context.getRuntime();
         ByteList tmp = ByteList.create(System.getProperty("java.io.tmpdir")); // default for all platforms except Windows
-        
         if (Platform.IS_WINDOWS) {
             String commonAppData = System.getenv("CSIDL_COMMON_APPDATA");
-            // TODO: need fallback mechanism
             if (commonAppData != null) tmp = ByteList.create(commonAppData);
         }
         RubyString ret = RubyString.newString(runtime, tmp, runtime.getDefaultExternalEncoding());
         ret.untaint(context);
-        ret.trust(context);
-        
+
         return ret;
     }
     
-    @JRubyMethod(name = "sysconfdir", module = true, compat = CompatVersion.RUBY1_9)
-    public static IRubyObject sysconfdir(ThreadContext context, IRubyObject recv) {
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject sysconfdir(ThreadContext context, IRubyObject recv) {
         Ruby runtime = context.getRuntime();
         ByteList tmp = ByteList.create(RbConfigLibrary.getSysConfDir(runtime)); // default for all platforms except Windows
         
@@ -437,10 +441,39 @@ public class RubyEtc {
         }
         RubyString ret = RubyString.newString(runtime, tmp, runtime.getDefaultExternalEncoding());
         ret.untaint(context);
-        ret.trust(context);
-        
+
         return ret;
     }
+
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject nprocessors(ThreadContext context, IRubyObject recv) {
+        int nprocs = Runtime.getRuntime().availableProcessors();
+        return RubyFixnum.newFixnum(context.getRuntime(), nprocs);
+    }
+
+    @JRubyMethod(module = true)
+    public static synchronized IRubyObject uname(ThreadContext context, IRubyObject self) {
+        Ruby runtime = context.runtime;
+        RubyHash uname = RubyHash.newHash(runtime);
+
+        uname.op_aset(context,
+                runtime.newSymbol("sysname"),
+                runtime.newString(SafePropertyAccessor.getProperty("os.name", "unknown")));
+        try {
+            uname.op_aset(context,
+                    runtime.newSymbol("nodename"),
+                    runtime.newString(InetAddress.getLocalHost().getHostName()));
+        } catch (UnknownHostException uhe) {
+            uname.op_aset(context,
+                    runtime.newSymbol("nodename"),
+                    runtime.newString("unknown"));
+        }
+        uname.put(runtime.newSymbol("release"), runtime.newString("unknown"));
+        uname.put(runtime.newSymbol("version"), runtime.newString(SafePropertyAccessor.getProperty("os.version")));
+        uname.put(runtime.newSymbol("machine"), runtime.newString(SafePropertyAccessor.getProperty("os.arch")));
+
+        return uname;
+    }
     
     private static final AtomicBoolean iteratingPasswd = new AtomicBoolean(false);
 }
