@@ -1,9 +1,9 @@
 /*
  ***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -96,8 +96,15 @@ public class RipperLexer extends LexingCommon {
     public boolean ignoreNextScanEvent = false;
 
     protected void ambiguousOperator(String op, String syn) {
-        warn("`" + op + "' after local variable or literal is interpreted as binary operator");
-        warn("even though it seems like " + syn);
+        parser.dispatch("on_operator_ambiguous", getRuntime().newSymbol(op), getRuntime().newString(syn));
+    }
+
+    protected boolean onMagicComment(String name, ByteList value) {
+        boolean found = super.onMagicComment(name, value);
+
+        parser.dispatch("on_magic_comment", getRuntime().newString(name), getRuntime().newString(value));
+
+        return found;
     }
 
     private int getFloatToken(String number, int suffix) {
@@ -336,7 +343,7 @@ public class RipperLexer extends LexingCommon {
         String value = createTokenString();
 
         if (!isLexState(last_state, EXPR_DOT|EXPR_FNAME) && parser.getCurrentScope().isDefined(value) >= 0) {
-            setState(EXPR_END|EXPR_LABEL);
+            setState(EXPR_END);
         }
 
         identValue = value.intern();
@@ -762,11 +769,10 @@ public class RipperLexer extends LexingCommon {
         
         ruby_sourceline = delayed_line;
         tokp = lex_pbeg + delayed_col;
-        
-        //System.out.println("TOKP: " + tokp + ", LEX_P: " + lex_p);        
-        IRubyObject value = parser.getRuntime().newString(delayed.dup());
+
         String event = tokenToEventId(token);
-        //System.out.println("EVENT: " + event + ", VALUE: " + value);
+        IRubyObject value = delayed == null ? parser.context.nil : parser.getRuntime().newString(delayed.dup());
+        
         yaccValue = parser.dispatch(event, value);
         delayed = null;
         ruby_sourceline = saved_line;
@@ -1213,6 +1219,7 @@ public class RipperLexer extends LexingCommon {
                 c = nextc();
                 if (c == '\n') {
                     spaceSeen = true;
+                    dispatchScanEvent(Tokens.tSP);
                     continue;
                 }
                 pushback(c);
@@ -1240,10 +1247,9 @@ public class RipperLexer extends LexingCommon {
     }
 
     private int identifierToken(int last_state, int result, String value) {
-
-        if (result == Tokens.tIDENTIFIER && !isLexState(last_state, EXPR_DOT) &&
+        if (result == Tokens.tIDENTIFIER && !isLexState(last_state, EXPR_DOT|EXPR_FNAME) &&
                 parser.getCurrentScope().isDefined(value) >= 0) {
-            setState(EXPR_END);
+            setState(EXPR_END|EXPR_LABEL);
         }
 
         identValue = value.intern();
@@ -1621,8 +1627,8 @@ public class RipperLexer extends LexingCommon {
         
         int result = 0;
 
-        String tempVal;
         last_state = lex_state;
+        String tempVal;
         if (lastBangOrPredicate) {
             result = Tokens.tFID;
             tempVal = createTokenString();
@@ -1644,6 +1650,7 @@ public class RipperLexer extends LexingCommon {
                 }
             }
             tempVal = createTokenString();
+
             if (result == 0 && Character.isUpperCase(tempVal.charAt(0))) {
                 result = Tokens.tCONSTANT;
             } else {
@@ -2392,18 +2399,7 @@ public class RipperLexer extends LexingCommon {
     // This is different than MRI in that we return a boolean since we only care whether it was added
     // or not.  The MRI version returns the byte supplied which is never used as a value.
     public boolean tokenAddMBC(int first_byte, ByteList buffer) {
-        int length = precise_mbclen();
-
-        if (length <= 0) {
-            compile_error("invalid multibyte char (" + getEncoding().getName() + ")");
-            return false;
-        }
-
-        tokAdd(first_byte, buffer);                  // add first byte since we have it.
-        lex_p += length - 1;                         // we already read first byte so advance pointer for remainder
-        if (length > 1) tokCopy(length - 1, buffer); // copy next n bytes over.
-
-        return true;
+        return tokadd_mbchar(first_byte, buffer);
     }
 
     // MRI: parser_tokadd_utf8 sans regexp literal parsing
