@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -40,6 +40,7 @@ import java.net.ProtocolFamily;
 import java.net.SocketAddress;
 import java.net.SocketException;
 import java.net.MulticastSocket;
+import java.net.SocketOption;
 import java.net.StandardProtocolFamily;
 import java.net.UnknownHostException;
 import java.net.DatagramPacket;
@@ -48,6 +49,7 @@ import java.nio.channels.Channel;
 import java.nio.channels.DatagramChannel;
 import java.nio.channels.IllegalBlockingModeException;
 import java.nio.channels.NotYetConnectedException;
+import java.nio.channels.UnsupportedAddressTypeException;
 
 import jnr.constants.platform.AddressFamily;
 import jnr.netdb.Service;
@@ -123,12 +125,18 @@ public class RubyUDPSocket extends RubyIPSocket {
         Ruby runtime = context.runtime;
 
         try {
+            this.family = family;
             DatagramChannel channel = DatagramChannel.open(family);
             initSocket(newChannelFD(runtime, channel));
         } catch (ConnectException e) {
             throw runtime.newErrnoECONNREFUSEDError();
         } catch (UnknownHostException e) {
             throw SocketUtils.sockerr(runtime, "initialize: name or service not known");
+        } catch (UnsupportedOperationException uoe) {
+            if (uoe.getMessage().contains("IPv6 not available")) {
+                throw runtime.newErrnoEAFNOSUPPORTError("socket(2) - udp");
+            }
+            throw sockerr(runtime, "UnsupportedOperationException: " + uoe.getLocalizedMessage(), uoe);
         } catch (IOException e) {
             throw sockerr(runtime, "initialize: name or service not known", e);
         }
@@ -183,6 +191,11 @@ public class RubyUDPSocket extends RubyIPSocket {
 
             return RubyFixnum.zero(runtime);
         }
+        catch (UnsupportedAddressTypeException e) {
+            // This may not be the appropriate message for all such exceptions
+            ProtocolFamily family = this.family == null ? StandardProtocolFamily.INET : this.family;
+            throw SocketUtils.sockerr(runtime, "bind: unsupported address " + host.inspect() + " for protocol family " + family);
+        }
         catch (UnknownHostException e) {
             throw SocketUtils.sockerr(runtime, "bind: name or service not known");
         }
@@ -625,6 +638,7 @@ public class RubyUDPSocket extends RubyIPSocket {
     }
 
     private volatile Class<? extends InetAddress> explicitFamily;
+    private volatile ProtocolFamily family;
 
     @Deprecated
     public IRubyObject bind(IRubyObject host, IRubyObject port) {
