@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -41,7 +41,7 @@ public abstract class DelegatingDynamicMethod extends DynamicMethod {
     protected final DynamicMethod delegate;
 
     public DelegatingDynamicMethod(DynamicMethod delegate) {
-        super(delegate.getImplementationClass(), delegate.getVisibility());
+        super(delegate.getImplementationClass(), delegate.getVisibility(), delegate.getName());
         this.delegate = delegate;
     }
 
@@ -168,11 +168,6 @@ public abstract class DelegatingDynamicMethod extends DynamicMethod {
         return delegate.getName();    //To change body of overridden methods use File | Settings | File Templates.
     }
 
-    @Override
-    public void setName(String name) {
-        delegate.setName(name);    //To change body of overridden methods use File | Settings | File Templates.
-    }
-
     @Override
     public boolean isNotImplemented() {
         return delegate.isNotImplemented();    //To change body of overridden methods use File | Settings | File Templates.
