@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -30,6 +30,10 @@
 
 package org.jruby.internal.runtime.methods;
 
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
 import java.lang.reflect.Method;
 import java.util.Arrays;
 import org.jruby.MetaClass;
@@ -65,24 +69,16 @@ public abstract class DynamicMethod {
     /** Flags for builtin, notimpl, etc */
     protected byte flags;
     /** The simple, base name this method was defined under. May be null.*/
-    protected String name;
+    protected final String name;
     /** An arbitrarily-typed "method handle" for use by compilers and call sites */
     protected Object handle;
 
     private static final int BUILTIN_FLAG = 0x1;
     private static final int NOTIMPL_FLAG = 0x2;
 
-    /**
-     * Base constructor for dynamic method handles.
-     *
-     * @param implementationClass The class to which this method will be
-     * immediately bound
-     * @param visibility The visibility assigned to this method
-     * pre/post invocation logic.
-     */
-    protected DynamicMethod(RubyModule implementationClass, Visibility visibility) {
-        assert implementationClass != null;
-        init(implementationClass, visibility);
+    @Retention(RetentionPolicy.RUNTIME)
+    public @interface Version {
+        int version = 0;
     }
 
     /**
@@ -94,18 +90,24 @@ public abstract class DynamicMethod {
      * @param name The simple name of this method
      */
     protected DynamicMethod(RubyModule implementationClass, Visibility visibility, String name) {
-        this(implementationClass, visibility);
+        assert implementationClass != null;
+        if (name == null) {
+            name = "null";
+        }
         this.name = name;
+        init(implementationClass, visibility);
     }
 
     /**
      * A no-arg constructor used only by the UndefinedMethod subclass and
      * CompiledMethod handles. instanceof assertions make sure this is so.
      */
-    protected DynamicMethod() {
-//        assert (this instanceof UndefinedMethod ||
-//                this instanceof CompiledMethod ||
-//                this instanceof );
+    protected DynamicMethod(String name) {
+        this.visibility = (byte) Visibility.PUBLIC.ordinal();
+        if (name == null) {
+            name = "null";
+        }
+        this.name = name;
     }
 
     protected void init(RubyModule implementationClass, Visibility visibility) {
@@ -393,7 +395,7 @@ public abstract class DynamicMethod {
     /**
      * Get the "real" method contained within this method. This simply returns
      * self except in cases where a method is wrapped to give it a new
-     * name or new implementation class (AliasMethod, WrapperMethod, ...).
+     * name or new implementation class (AliasMethod, PartialDelegatingMethod, ...).
      *
      * @return The "real" method associated with this one
      */
@@ -491,15 +493,6 @@ public abstract class DynamicMethod {
         return name;
     }
 
-    /**
-     * Set the base name for this method.
-     *
-     * @param name the name to set
-     */
-    public void setName(String name) {
-        this.name = name;
-    }
-
     /**
      * Get the "handle" associated with this DynamicMethod.
      * 
@@ -568,4 +561,12 @@ public abstract class DynamicMethod {
     @Deprecated
     public void setCallConfig(CallConfiguration callConfig) {
     }
+
+    /**
+     * @deprecated Use {@link DynamicMethod#DynamicMethod(RubyModule, Visibility, String)}
+     */
+    @Deprecated
+    protected DynamicMethod(RubyModule implementationClass, Visibility visibility) {
+        this(implementationClass, visibility, "(anonymous)");
+    }
 }
