@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -83,17 +83,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
         {null, null, null, JavaMethodThreeOrNBlock.class},
     };
 
-
-    public JavaMethod(RubyModule implementationClass, Visibility visibility) {
-        this(implementationClass, visibility, CallConfiguration.FrameFullScopeNone);
-    }
-
     public JavaMethod(RubyModule implementationClass, Visibility visibility, String name) {
         super(implementationClass, visibility, name);
     }
 
-    protected JavaMethod() {}
-
     public void init(RubyModule implementationClass, Arity arity, Visibility visibility, StaticScope staticScope) {
         this.staticScope = staticScope;
         setArity(arity);
@@ -278,13 +271,14 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement N with block
     public static abstract class JavaMethodNBlock extends JavaMethod {
-        public JavaMethodNBlock(RubyModule implementationClass, Visibility visibility) {
-            super(implementationClass, visibility);
-        }
         public JavaMethodNBlock(RubyModule implementationClass, Visibility visibility, String name) {
             super(implementationClass, visibility, name);
         }
         @Deprecated
+        public JavaMethodNBlock(RubyModule implementationClass, Visibility visibility) {
+            super(implementationClass, visibility);
+        }
+        @Deprecated
         public JavaMethodNBlock(RubyModule implementationClass, Visibility visibility, CallConfiguration callConfig) {
             super(implementationClass, visibility);
         }
@@ -297,6 +291,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement zero to N with block
     public static abstract class JavaMethodZeroOrNBlock extends JavaMethodNBlock {
+        public JavaMethodZeroOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -315,6 +313,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrNBlock extends JavaMethodZeroOrNBlock {
+        public JavaMethodZeroOrOneOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -333,6 +335,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwoOrNBlock extends JavaMethodZeroOrOneOrNBlock {
+        public JavaMethodZeroOrOneOrTwoOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwoOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -351,6 +357,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwoOrThreeOrNBlock extends JavaMethodZeroOrOneOrTwoOrNBlock {
+        public JavaMethodZeroOrOneOrTwoOrThreeOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwoOrThreeOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -371,6 +381,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement one to N with block
     public static abstract class JavaMethodOneOrNBlock extends JavaMethodNBlock {
+        public JavaMethodOneOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -389,6 +403,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwoOrNBlock extends JavaMethodOneOrNBlock {
+        public JavaMethodOneOrTwoOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwoOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -407,6 +425,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwoOrThreeOrNBlock extends JavaMethodOneOrTwoOrNBlock {
+        public JavaMethodOneOrTwoOrThreeOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwoOrThreeOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -427,6 +449,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement two to N with block
     public static abstract class JavaMethodTwoOrNBlock extends JavaMethodNBlock {
+        public JavaMethodTwoOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodTwoOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -445,6 +471,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodTwoOrThreeOrNBlock extends JavaMethodTwoOrNBlock {
+        public JavaMethodTwoOrThreeOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodTwoOrThreeOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -465,6 +495,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement three to N with block
     public static abstract class JavaMethodThreeOrNBlock extends JavaMethodNBlock {
+        public JavaMethodThreeOrNBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodThreeOrNBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -485,6 +519,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement zero to three with block
     public static abstract class JavaMethodZeroBlock extends JavaMethodZeroOrNBlock {
+        public JavaMethodZeroBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -500,6 +538,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneBlock extends JavaMethodZeroOrOneOrNBlock {
+        public JavaMethodZeroOrOneBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -521,6 +563,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwoBlock extends JavaMethodZeroOrOneOrTwoOrNBlock {
+        public JavaMethodZeroOrOneOrTwoBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwoBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -544,6 +590,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwoOrThreeBlock extends JavaMethodZeroOrOneOrTwoOrThreeOrNBlock {
+        public JavaMethodZeroOrOneOrTwoOrThreeBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwoOrThreeBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -570,6 +620,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement one to three with block
     public static abstract class JavaMethodOneBlock extends JavaMethodOneOrNBlock {
+        public JavaMethodOneBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -590,6 +644,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwoBlock extends JavaMethodOneOrTwoOrNBlock {
+        public JavaMethodOneOrTwoBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwoBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -611,6 +669,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwoOrThreeBlock extends JavaMethodOneOrTwoOrThreeOrNBlock {
+        public JavaMethodOneOrTwoOrThreeBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwoOrThreeBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -636,6 +698,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement two to three with block
     public static abstract class JavaMethodTwoBlock extends JavaMethodTwoOrNBlock {
+        public JavaMethodTwoBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodTwoBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -651,6 +717,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodTwoOrThreeBlock extends JavaMethodTwoOrThreeOrNBlock {
+        public JavaMethodTwoOrThreeBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodTwoOrThreeBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -674,6 +744,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement three with block
     public static abstract class JavaMethodThreeBlock extends JavaMethodThreeOrNBlock {
+        public JavaMethodThreeBlock(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodThreeBlock(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -690,13 +764,14 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement N
     public static abstract class JavaMethodN extends JavaMethodNBlock {
-        public JavaMethodN(RubyModule implementationClass, Visibility visibility) {
-            super(implementationClass, visibility);
-        }
         public JavaMethodN(RubyModule implementationClass, Visibility visibility, String name) {
             super(implementationClass, visibility, name);
         }
         @Deprecated
+        public JavaMethodN(RubyModule implementationClass, Visibility visibility) {
+            super(implementationClass, visibility);
+        }
+        @Deprecated
         public JavaMethodN(RubyModule implementationClass, Visibility visibility, CallConfiguration callConfig) {
             super(implementationClass, visibility);
         }
@@ -749,13 +824,14 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement zero to N
     public static abstract class JavaMethodZeroOrN extends JavaMethodN {
-        public JavaMethodZeroOrN(RubyModule implementationClass, Visibility visibility) {
-            super(implementationClass, visibility);
-        }
         public JavaMethodZeroOrN(RubyModule implementationClass, Visibility visibility, String name) {
             super(implementationClass, visibility, name);
         }
         @Deprecated
+        public JavaMethodZeroOrN(RubyModule implementationClass, Visibility visibility) {
+            super(implementationClass, visibility);
+        }
+        @Deprecated
         public JavaMethodZeroOrN(RubyModule implementationClass, Visibility visibility, CallConfiguration callConfig) {
             super(implementationClass, visibility);
         }
@@ -774,6 +850,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrN extends JavaMethodZeroOrN {
+        public JavaMethodZeroOrOneOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -792,6 +872,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwoOrN extends JavaMethodZeroOrOneOrN {
+        public JavaMethodZeroOrOneOrTwoOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwoOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -810,6 +894,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwoOrThreeOrN extends JavaMethodZeroOrOneOrTwoOrN {
+        public JavaMethodZeroOrOneOrTwoOrThreeOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwoOrThreeOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -830,13 +918,14 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement one to N
     public static abstract class JavaMethodOneOrN extends JavaMethodN {
-        public JavaMethodOneOrN(RubyModule implementationClass, Visibility visibility) {
-            super(implementationClass, visibility);
-        }
         public JavaMethodOneOrN(RubyModule implementationClass, Visibility visibility, String name) {
             super(implementationClass, visibility, name);
         }
         @Deprecated
+        public JavaMethodOneOrN(RubyModule implementationClass, Visibility visibility) {
+            super(implementationClass, visibility);
+        }
+        @Deprecated
         public JavaMethodOneOrN(RubyModule implementationClass, Visibility visibility, CallConfiguration callConfig) {
             super(implementationClass, visibility);
         }
@@ -855,6 +944,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwoOrN extends JavaMethodOneOrN {
+        public JavaMethodOneOrTwoOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwoOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -873,6 +966,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwoOrThreeOrN extends JavaMethodOneOrTwoOrN {
+        public JavaMethodOneOrTwoOrThreeOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwoOrThreeOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -893,6 +990,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement two to N
     public static abstract class JavaMethodTwoOrN extends JavaMethodN {
+        public JavaMethodTwoOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodTwoOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -911,6 +1012,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodTwoOrThreeOrN extends JavaMethodTwoOrN {
+        public JavaMethodTwoOrThreeOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodTwoOrThreeOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -931,6 +1036,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement three to N
     public static abstract class JavaMethodThreeOrN extends JavaMethodN {
+        public JavaMethodThreeOrN(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodThreeOrN(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -951,13 +1060,14 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement zero to three
     public static abstract class JavaMethodZero extends JavaMethodZeroOrN {
-        public JavaMethodZero(RubyModule implementationClass, Visibility visibility) {
-            super(implementationClass, visibility);
-        }
         public JavaMethodZero(RubyModule implementationClass, Visibility visibility, String name) {
             super(implementationClass, visibility, name);
         }
         @Deprecated
+        public JavaMethodZero(RubyModule implementationClass, Visibility visibility) {
+            super(implementationClass, visibility);
+        }
+        @Deprecated
         public JavaMethodZero(RubyModule implementationClass, Visibility visibility, CallConfiguration callConfig) {
             super(implementationClass, visibility);
         }
@@ -977,6 +1087,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOne extends JavaMethodZeroOrOneOrN {
+        public JavaMethodZeroOrOne(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOne(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -999,6 +1113,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwo extends JavaMethodZeroOrOneOrTwoOrN {
+        public JavaMethodZeroOrOneOrTwo(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwo(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -1023,6 +1141,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodZeroOrOneOrTwoOrThree extends JavaMethodZeroOrOneOrTwoOrThreeOrN {
+        public JavaMethodZeroOrOneOrTwoOrThree(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodZeroOrOneOrTwoOrThree(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -1050,15 +1172,16 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement one to three
     public static abstract class JavaMethodOne extends JavaMethodOneOrN {
-        public JavaMethodOne(RubyModule implementationClass, Visibility visibility) {
-            super(implementationClass, visibility);
-            setParameterList(ONE_REQ);
-        }
         public JavaMethodOne(RubyModule implementationClass, Visibility visibility, String name) {
             super(implementationClass, visibility, name);
             setParameterList(ONE_REQ);
         }
         @Deprecated
+        public JavaMethodOne(RubyModule implementationClass, Visibility visibility) {
+            super(implementationClass, visibility);
+            setParameterList(ONE_REQ);
+        }
+        @Deprecated
         public JavaMethodOne(RubyModule implementationClass, Visibility visibility, CallConfiguration callConfig) {
             super(implementationClass, visibility);
             setParameterList(ONE_REQ);
@@ -1081,6 +1204,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwo extends JavaMethodOneOrTwoOrN {
+        public JavaMethodOneOrTwo(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwo(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -1102,6 +1229,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodOneOrTwoOrThree extends JavaMethodOneOrTwoOrThreeOrN {
+        public JavaMethodOneOrTwoOrThree(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+        }
+        @Deprecated
         public JavaMethodOneOrTwoOrThree(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -1127,6 +1258,11 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement two to three
     public static abstract class JavaMethodTwo extends JavaMethodTwoOrN {
+        public JavaMethodTwo(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+            setParameterList(TWO_REQ);
+        }
+        @Deprecated
         public JavaMethodTwo(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
             setParameterList(TWO_REQ);
@@ -1149,6 +1285,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     }
 
     public static abstract class JavaMethodTwoOrThree extends JavaMethodTwoOrThreeOrN {
+        public JavaMethodTwoOrThree(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+            setParameterList(TWO_REQ);
+        }
         public JavaMethodTwoOrThree(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
         }
@@ -1172,6 +1312,10 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
 
     // promise to implement three
     public static abstract class JavaMethodThree extends JavaMethodThreeOrN {
+        public JavaMethodThree(RubyModule implementationClass, Visibility visibility, String name) {
+            super(implementationClass, visibility, name);
+            setParameterList(THREE_REQ);
+        }
         public JavaMethodThree(RubyModule implementationClass, Visibility visibility) {
             super(implementationClass, visibility);
             setParameterList(THREE_REQ);
@@ -1215,4 +1359,15 @@ public abstract class JavaMethod extends DynamicMethod implements Cloneable, Met
     @Deprecated
     public void setCallerRequirement(CallConfiguration callerRequirement) {
     }
+
+    /**
+     * Used for old-style nameless constructor to pass name in out-of-band.
+     */
+    @Deprecated
+    public static final ThreadLocal<String> NAME_PASSER = new ThreadLocal<>();
+
+    @Deprecated
+    public JavaMethod(RubyModule implementationClass, Visibility visibility) {
+        this(implementationClass, visibility, NAME_PASSER.get());
+    }
 }
