@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -53,9 +53,9 @@ public class ProcMethod extends DynamicMethod implements PositionAware, IRMethod
      * Constructor for ProcMethod.
      * @param visibility
      */
-    public ProcMethod(RubyModule implementationClass, RubyProc proc, Visibility visibility) {
+    public ProcMethod(RubyModule implementationClass, RubyProc proc, Visibility visibility, String name) {
         // FIXME: set up a call configuration for this
-        super(implementationClass, visibility);
+        super(implementationClass, visibility, name);
         this.proc = proc;
     }
 
@@ -64,7 +64,7 @@ public class ProcMethod extends DynamicMethod implements PositionAware, IRMethod
     }
     
     public DynamicMethod dup() {
-        return new ProcMethod(getImplementationClass(), proc, getVisibility());
+        return new ProcMethod(getImplementationClass(), proc, getVisibility(), name);
     }
 
     // TODO: Push isSame up to DynamicMethod to simplify general equality
