@@ -2,20 +2,14 @@ package org.jruby.ir;
 
 import org.jruby.parser.StaticScope;
 
-/**
- */
 public class IRClassBody extends IRModuleBody {
     public IRClassBody(IRManager manager, IRScope lexicalParent, String name, int lineNumber, StaticScope scope) {
         super(manager, lexicalParent, name, lineNumber, scope);
     }
 
-    public IRClassBody(IRManager manager, IRScope lexicalParent, String name, String fileName, int lineNumber, StaticScope scope) {
-        super(manager, lexicalParent, name, fileName, lineNumber, scope);
-    }
-
     @Override
-    public String getScopeName() {
-        return "ClassBody";
+    public IRScopeType getScopeType() {
+        return IRScopeType.CLASS_BODY;
     }
 
     @Override
