@@ -425,6 +425,10 @@ public abstract class CallBase extends NOperandInstr implements ClosureAccepting
         IRubyObject[] values = prepareArguments(context, self, currScope, dynamicScope, temp);
         Block preparedBlock = prepareBlock(context, self, currScope, dynamicScope, temp);
 
+        if (hasLiteralClosure()) {
+            return callSite.callIter(context, self, object, values, preparedBlock);
+        }
+
         return callSite.call(context, self, object, values, preparedBlock);
     }
 
