@@ -38,6 +38,10 @@ public abstract class TwoOperandBranchInstr extends BranchInstr {
         }
     }
 
+    public void setJumpTarget(Label target) {
+        this.jumpTarget = target;
+    }
+
     public Label getJumpTarget() {
         return jumpTarget;
     }
