@@ -12,9 +12,13 @@ import org.jruby.runtime.ThreadContext;
  * way I got lazy and removed protected.
  */
 public class Nil extends ImmutableLiteral {
+    public Nil() {
+        super();
+    }
+
     @Override
-    public Object createCacheObject(ThreadContext context) {
-        return context.nil;
+    public OperandType getOperandType() {
+        return OperandType.NIL;
     }
 
     @Override
@@ -22,6 +26,11 @@ public class Nil extends ImmutableLiteral {
         return "nil";
     }
 
+    @Override
+    public Object createCacheObject(ThreadContext context) {
+        return context.nil;
+    }
+
     @Override
     public void visit(IRVisitor visitor) {
         visitor.Nil(this);
