@@ -142,27 +142,57 @@ public class Bootstrap {
     }
 
     public static Handle string() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "string", sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, String.class, int.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "string",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, String.class, int.class),
+                false);
     }
 
     public static Handle fstring() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "fstring", sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, String.class, int.class, String.class, int.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "fstring",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, String.class, int.class, String.class, int.class),
+                false);
     }
 
     public static Handle bytelist() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "bytelist", sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, String.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "bytelist",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, String.class),
+                false);
     }
 
     public static Handle array() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "array", sig(CallSite.class, Lookup.class, String.class, MethodType.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "array",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class),
+                false);
     }
 
     public static Handle hash() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "hash", sig(CallSite.class, Lookup.class, String.class, MethodType.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "hash",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class),
+                false);
     }
 
     public static Handle kwargsHash() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "kwargsHash", sig(CallSite.class, Lookup.class, String.class, MethodType.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "kwargsHash",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class),
+                false);
     }
 
     public static Handle invokeSuper() {
@@ -170,11 +200,21 @@ public class Bootstrap {
     }
 
     public static Handle ivar() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "ivar", sig(CallSite.class, Lookup.class, String.class, MethodType.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "ivar",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class),
+                false);
     }
 
     public static Handle global() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "globalBootstrap", sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, int.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "globalBootstrap",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class, int.class),
+                false);
     }
 
     public static RubyString string(MutableCallSite site, ByteList value, int cr, ThreadContext context) throws Throwable {
@@ -215,11 +255,21 @@ public class Bootstrap {
     }
 
     public static Handle contextValue() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "contextValue", sig(CallSite.class, Lookup.class, String.class, MethodType.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "contextValue",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class),
+                false);
     }
 
     public static Handle contextValueString() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "contextValueString", sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "contextValueString",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class, String.class),
+                false);
     }
 
     public static CallSite contextValue(Lookup lookup, String name, MethodType type) {
@@ -485,7 +535,7 @@ public class Bootstrap {
             // Temporary fix for missing kwargs dup+splitting logic from frobnicate, called by CompiledIRMethod but
             // skipped by indy's direct binding.
             if (compiledIRMethod.hasKwargs()) return null;
-            
+
             // attempt IR direct binding
             // TODO: this will have to expand when we start specializing arities
 
@@ -845,7 +895,12 @@ public class Bootstrap {
     }
 
     public static Handle getBootstrapHandle(String name, Class type, String sig) {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(type), name, sig);
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(type),
+                name,
+                sig,
+                false);
     }
 
     public static CallSite checkpointBootstrap(Lookup lookup, String name, MethodType type) throws Throwable {
@@ -949,7 +1004,12 @@ public class Bootstrap {
     }
 
     public static Handle prepareBlock() {
-        return new Handle(Opcodes.H_INVOKESTATIC, p(Bootstrap.class), "prepareBlock", sig(CallSite.class, Lookup.class, String.class, MethodType.class, MethodHandle.class, MethodHandle.class, long.class));
+        return new Handle(
+                Opcodes.H_INVOKESTATIC,
+                p(Bootstrap.class),
+                "prepareBlock",
+                sig(CallSite.class, Lookup.class, String.class, MethodType.class, MethodHandle.class, MethodHandle.class, long.class),
+                false);
     }
 
     public static CallSite prepareBlock(Lookup lookup, String name, MethodType type, MethodHandle bodyHandle, MethodHandle scopeHandle, long encodedSignature) throws Throwable {
