@@ -33,6 +33,9 @@ import java.lang.invoke.MethodHandles;
 import java.lang.invoke.MethodType;
 import java.lang.invoke.MutableCallSite;
 import java.lang.invoke.SwitchPoint;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.Map;
 import java.util.concurrent.atomic.AtomicLong;
 
 import static java.lang.invoke.MethodHandles.lookup;
@@ -53,6 +56,7 @@ public abstract class InvokeSite extends MutableCallSite {
     protected final String file;
     protected final int line;
     private boolean boundOnce;
+    private boolean literalClosure;
     CacheEntry cache = CacheEntry.NULL_CACHE;
 
     private static final Logger LOG = LoggerFactory.getLogger(InvokeSite.class);
@@ -64,9 +68,14 @@ public abstract class InvokeSite extends MutableCallSite {
     public final CallType callType;
 
     public InvokeSite(MethodType type, String name, CallType callType, String file, int line) {
+        this(type, name, callType, false, file, line);
+    }
+
+    public InvokeSite(MethodType type, String name, CallType callType, boolean literalClosure, String file, int line) {
         super(type);
         this.methodName = name;
         this.callType = callType;
+        this.literalClosure = literalClosure;
         this.file = file;
         this.line = line;
 
@@ -140,11 +149,41 @@ public abstract class InvokeSite extends MutableCallSite {
 
         MethodHandle mh = getHandle(self, selfClass, method);
 
+        if (literalClosure) {
+            mh = Binder.from(mh.type())
+                    .tryFinally(getBlockEscape(signature))
+                    .invoke(mh);
+        }
+
         updateInvocationTarget(mh, self, selfClass, entry.method, switchPoint);
 
+        if (literalClosure) {
+            try {
+                return method.call(context, self, selfClass, methodName, args, block);
+            } finally {
+                block.escape();
+            }
+        }
+
         return method.call(context, self, selfClass, methodName, args, block);
     }
 
+    private static final MethodHandle ESCAPE_BLOCK = Binder.from(void.class, Block.class).invokeVirtualQuiet(lookup(), "escape");
+    private static final Map<Signature, MethodHandle> BLOCK_ESCAPES = Collections.synchronizedMap(new HashMap<Signature, MethodHandle>());
+
+    private static MethodHandle getBlockEscape(Signature signature) {
+        Signature voidSignature = signature.changeReturn(void.class);
+        MethodHandle escape = BLOCK_ESCAPES.get(voidSignature);
+        if (escape == null) {
+            escape = SmartBinder.from(voidSignature)
+                    .permute("block")
+                    .invoke(ESCAPE_BLOCK)
+                    .handle();
+            BLOCK_ESCAPES.put(voidSignature, escape);
+        }
+        return escape;
+    }
+
     /**
      * Failover version uses a monomorphic cache and DynamicMethod.call, as in non-indy.
      */
@@ -279,7 +318,7 @@ public abstract class InvokeSite extends MutableCallSite {
     MethodHandle getHandle(IRubyObject self, RubyClass dispatchClass, DynamicMethod method) throws Throwable {
         boolean blockGiven = signature.lastArgType() == Block.class;
 
-        MethodHandle mh = buildNewInstanceHandle(method, self, blockGiven);
+        MethodHandle mh = buildNewInstanceHandle(method, self);
         if (mh == null) mh = Bootstrap.buildNativeHandle(this, method, blockGiven);
         if (mh == null) mh = Bootstrap.buildIndyHandle(this, method, method.getImplementationClass());
         if (mh == null) mh = Bootstrap.buildJittedHandle(this, method, blockGiven);
@@ -291,14 +330,14 @@ public abstract class InvokeSite extends MutableCallSite {
         return mh;
     }
 
-    MethodHandle buildNewInstanceHandle(DynamicMethod method, IRubyObject self, boolean blockGiven) {
+    MethodHandle buildNewInstanceHandle(DynamicMethod method, IRubyObject self) {
         MethodHandle mh = null;
 
         if (method == self.getRuntime().getBaseNewMethod()) {
             RubyClass recvClass = (RubyClass) self;
 
             // Bind a second site as a dynamic invoker to guard against changes in new object's type
-            CallSite initSite = SelfInvokeSite.bootstrap(lookup(), "callFunctional:initialize", type(), file, line);
+            CallSite initSite = SelfInvokeSite.bootstrap(lookup(), "callFunctional:initialize", type(), literalClosure ? 1 : 0, file, line);
             MethodHandle initHandle = initSite.dynamicInvoker();
 
             MethodHandle allocFilter = Binder.from(IRubyObject.class, IRubyObject.class)
