@@ -1,5 +1,6 @@
 package org.jruby.javasupport.binding;
 
+import com.headius.modulator.Modulator;
 import org.jruby.Ruby;
 import org.jruby.RubyClass;
 import org.jruby.RubyModule;
@@ -418,7 +419,7 @@ public abstract class Initializer {
             else { // lower-case name
                 if ( ! proxy.respondsTo(simpleName) ) {
                     // define a class method
-                    proxy.getSingletonClass().addMethod(simpleName, new JavaMethod.JavaMethodZero(proxy.getSingletonClass(), PUBLIC) {
+                    proxy.getSingletonClass().addMethod(simpleName, new JavaMethod.JavaMethodZero(proxy.getSingletonClass(), PUBLIC, simpleName) {
                         @Override
                         public IRubyObject call(ThreadContext context, IRubyObject self, RubyModule clazz, String name) {
                             return innerProxy;
@@ -539,6 +540,9 @@ public abstract class Initializer {
             // Skip private methods, since they may mess with dispatch
             if ( Modifier.isPrivate(mod) ) continue;
 
+            // Skip protected methods if we can't set accessible
+            if ( !Modifier.isPublic(mod) && !Modulator.trySetAccessible(method)) continue;
+
             // ignore bridge methods because we'd rather directly call methods that this method
             // is bridging (and such methods are by definition always available.)
             if ( ( mod & ACC_BRIDGE ) != 0 ) continue;
