@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -68,6 +68,13 @@ public abstract class JavaLang {
         final RubyModule byteArray = Java.getProxyClass(runtime, new byte[0].getClass());
         byteArray.addMethod("ubyte_get", new UByteGet(byteArray));
         byteArray.addMethod("ubyte_set", new UByteSet(byteArray));
+
+        final RubyModule String = Java.getProxyClass(runtime, java.lang.String.class);
+        String.defineAlias("to_str", "to_s");
+
+        final RubyModule Number = Java.getProxyClass(runtime, java.lang.Number.class);
+        Number.defineAlias("to_int", "longValue");
+        Number.defineAlias("to_f", "doubleValue");
     }
 
     @JRubyModule(name = "Java::JavaLang::Iterable", include = "Enumerable")
@@ -529,7 +536,7 @@ public abstract class JavaLang {
     private static final class UByteGet extends JavaMethod.JavaMethodOne {
 
         UByteGet(RubyModule implClass) {
-            super(implClass, PUBLIC);
+            super(implClass, PUBLIC, "ubyte_get");
         }
 
         @Override
@@ -544,7 +551,7 @@ public abstract class JavaLang {
     private static final class UByteSet extends JavaMethod.JavaMethodTwo {
 
         UByteSet(RubyModule implClass) {
-            super(implClass, PUBLIC);
+            super(implClass, PUBLIC, "ubyte_set");
         }
 
         @Override
