@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -226,8 +226,8 @@ public abstract class JavaUtil {
         @JRubyMethod
         public static IRubyObject dup(final ThreadContext context, final IRubyObject self) {
             java.util.Collection coll = unwrapIfJavaObject(self);
-            final JavaProxy dup = (JavaProxy) self.dup();
-            if ( coll == dup.getObject() ) { // not Cloneable
+            final JavaProxy dup = (JavaProxy) ((RubyBasicObject) self).dup();
+            if ( coll == dup.getObject() && ! (coll instanceof Cloneable) ) {
                 dup.setObject( tryNewEqualInstance(coll) );
             }
             return dup;
@@ -236,8 +236,8 @@ public abstract class JavaUtil {
         @JRubyMethod
         public static IRubyObject clone(final ThreadContext context, final IRubyObject self) {
             java.util.Collection coll = unwrapIfJavaObject(self);
-            final JavaProxy dup = (JavaProxy) self.rbClone();
-            if ( coll == dup.getObject() ) { // not Cloneable
+            final JavaProxy dup = (JavaProxy) ((RubyBasicObject) self).rbClone();
+            if ( coll == dup.getObject() && ! (coll instanceof Cloneable) ) {
                 dup.setObject( tryNewEqualInstance(coll) );
             }
             return dup;
@@ -608,8 +608,10 @@ public abstract class JavaUtil {
                     }
                 }
             }
-            if ( CAN_SET_ACCESSIBLE ) best.setAccessible(true);
-            return (java.util.Collection) best.newInstance(coll);
+            if ( best != null ) {
+                if ( CAN_SET_ACCESSIBLE ) best.setAccessible(true);
+                return (java.util.Collection) best.newInstance(coll);
+            }
         }
         catch (IllegalAccessException e) {
             // fallback on getConstructor();
