@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -37,7 +37,9 @@ import org.jruby.runtime.builtin.IRubyObject;
  */
 public interface JavaProxyInvocationHandler {
 
-    IRubyObject getOrig();
+    IRubyObject getOrig(); // rename to getTarget() ? returns self or null for proc based handler
+
+    // org.jruby.Ruby getRuntime();
 
     /**
      * Similar to {@link java.lang.reflect.InvocationHandler}
@@ -47,8 +49,7 @@ public interface JavaProxyInvocationHandler {
      * @param args
      * @return
      * @throws Throwable
-     * @see {@link InvocationHandler}
+     * @see java.lang.reflect.InvocationHandler#invoke(Object, java.lang.reflect.Method, Object[])
      */
-    Object invoke(Object receiver, JavaProxyMethod method, Object[] args)
-            throws Throwable;
+    Object invoke(Object receiver, JavaProxyMethod method, Object[] args) throws Throwable;
 }
\ No newline at end of file
