@@ -14,57 +14,57 @@ import java.util.concurrent.locks.ReentrantLock;
  * Maps Java objects to their proxies.  Combines elements of WeakHashMap and
  * ConcurrentHashMap to permit unsynchronized reads.  May be configured to
  * use either Weak (the default) or Soft references.<p>
- * 
+ *
  * Note that both Java objects and their proxies are held by weak/soft
  * references; because proxies (currently) keep strong references to their
  * Java objects, if we kept strong references to them the Java objects would
  * never be gc'ed.  This presents a problem in the case where a user passes
- * a Rubified Java object out to Java but keeps no reference in Ruby to the 
+ * a Rubified Java object out to Java but keeps no reference in Ruby to the
  * proxy; if the object is returned to Ruby after its proxy has been gc'ed,
  * a new (and possibly very wrong, in the case of JRuby-defined subclasses)
  * proxy will be created.  Use of soft references may help reduce the
  * likelihood of this occurring; users may be advised to keep Ruby-side
  * references to prevent it occurring altogether.
- * 
+ *
  * @author <a href="mailto:bill.dortch@gmail.com">Bill Dortch</a>
- * 
+ *
  */
 public abstract class ObjectProxyCache<T,A> {
 
-    private static final Logger LOG = LoggerFactory.getLogger("ObjectProxyCache");
-    
+    private static final Logger LOG = LoggerFactory.getLogger(ObjectProxyCache.class);
+
     public static enum ReferenceType { WEAK, SOFT }
-    
+
     private static final int DEFAULT_SEGMENTS = 16; // must be power of 2
     private static final int DEFAULT_SEGMENT_SIZE = 8; // must be power of 2
     private static final float DEFAULT_LOAD_FACTOR = 0.75f;
     private static final int MAX_CAPACITY = 1 << 30;
     private static final int MAX_SEGMENTS = 1 << 16;
     private static final int VULTURE_RUN_FREQ_SECONDS = 5;
-    
+
     private static int _nextId = 0;
-    
+
     private static synchronized int nextId() {
         return ++_nextId;
     }
 
-    
+
     private final ReferenceType referenceType;
     private final Segment<T,A>[] segments;
     private final int segmentShift;
     private final int segmentMask;
     private Thread vulture;
     private final int id;
-    
+
     public ObjectProxyCache() {
         this(DEFAULT_SEGMENTS, DEFAULT_SEGMENT_SIZE, ReferenceType.WEAK);
     }
-    
+
     public ObjectProxyCache(ReferenceType refType) {
         this(DEFAULT_SEGMENTS, DEFAULT_SEGMENT_SIZE, refType);
     }
-    
-    
+
+
     public ObjectProxyCache(int numSegments, int initialSegCapacity, ReferenceType refType) {
         if (numSegments <= 0 || initialSegCapacity <= 0 || refType == null) {
             throw new IllegalArgumentException();
@@ -72,7 +72,7 @@ public abstract class ObjectProxyCache<T,A> {
         this.id = nextId();
         this.referenceType = refType;
         if (numSegments > MAX_SEGMENTS) numSegments = MAX_SEGMENTS;
-    
+
         // Find power-of-two sizes best matching arguments
         int sshift = 0;
         int ssize = 1;
@@ -81,18 +81,18 @@ public abstract class ObjectProxyCache<T,A> {
             ssize <<= 1;
         }
         // note segmentShift differs from ConcurrentHashMap's calculation due to
-        // issues with System.identityHashCode (upper n bits always 0, at least 
+        // issues with System.identityHashCode (upper n bits always 0, at least
         // under Java 1.6 / WinXP)
         this.segmentShift = 24 - sshift;
         this.segmentMask = ssize - 1;
         this.segments = Segment.newArray(ssize);
-    
+
         if (initialSegCapacity > MAX_CAPACITY) {
             initialSegCapacity = MAX_CAPACITY;
         }
         int cap = 1;
         while (cap < initialSegCapacity) cap <<= 1;
-    
+
         for (int i = ssize; --i >= 0; ) {
             segments[i] = new Segment<T,A>(cap, this);
         }
@@ -138,38 +138,38 @@ public abstract class ObjectProxyCache<T,A> {
             this.vulture = null;
         }
 
-        
+
         // FIXME: vulture daemon thread prevents finalization,
         // find alternative approach.
         // vulture.start();
 
 //      System.err.println("***ObjectProxyCache " + id + " started at "+ new java.util.Date());
     }
-    
+
 //    protected void finalize() throws Throwable {
 //        System.err.println("***ObjectProxyCache " + id + " finalized at "+ new java.util.Date());
 //    }
-    
+
     public abstract T allocateProxy(Object javaObject, A allocator);
-    
+
     public T get(Object javaObject) {
         if (javaObject == null) return null;
         int hash = hash(javaObject);
         return segmentFor(hash).get(javaObject, hash);
     }
-    
+
     public T getOrCreate(Object javaObject, A allocator) {
         if (javaObject == null || allocator == null) return null;
         int hash = hash(javaObject);
         return segmentFor(hash).getOrCreate(javaObject, hash, allocator);
     }
-    
+
     public void put(Object javaObject, T proxy) {
         if (javaObject == null || proxy == null) return;
         int hash = hash(javaObject);
         segmentFor(hash).put(javaObject, hash, proxy);
     }
-    
+
     private static int hash(Object javaObject) {
         int h = System.identityHashCode(javaObject);
         h ^= (h >>> 20) ^ (h >>> 12);
@@ -179,13 +179,13 @@ public abstract class ObjectProxyCache<T,A> {
     private Segment<T,A> segmentFor(int hash) {
         return segments[(hash >>> segmentShift) & segmentMask];
     }
-    
+
     /**
      * Returns the approximate size (elements in use) of the cache. The
      * sizes of the segments are summed. No effort is made to synchronize
      * across segments, so the value returned may differ from the actual
      * size at any point in time.
-     * 
+     *
      * @return
      */
     public int size() {
@@ -195,7 +195,7 @@ public abstract class ObjectProxyCache<T,A> {
        }
        return size;
     }
-    
+
     public String stats() {
         StringBuilder b = new StringBuilder();
         int n = 0;
@@ -221,7 +221,7 @@ public abstract class ObjectProxyCache<T,A> {
             .append("  alloc: ").append(alloc).append("\n");
         return b.toString();
     }
-    
+
     // EntryRefs include hash with key to facilitate lookup by Segment#expunge
     // after ref is removed from ReferenceQueue
     private static interface EntryRef<T> {
@@ -261,7 +261,7 @@ public abstract class ObjectProxyCache<T,A> {
         final int hash;
         final EntryRef<T> proxyRef;
         final Entry<T> next;
-        
+
         Entry(Object object, int hash, T proxy, ReferenceType type, Entry<T> next, ReferenceQueue<Object> queue) {
             this.hash = hash;
             this.next = next;
@@ -277,7 +277,7 @@ public abstract class ObjectProxyCache<T,A> {
                 this.proxyRef = new SoftEntryRef<T>(hash, proxy, queue);
             }
         }
-        
+
         // ctor used by remove/rehash
         Entry(EntryRef<Object> objectRef, int hash, EntryRef<T> proxyRef, Entry<T> next) {
             this.objectRef = objectRef;
@@ -285,13 +285,13 @@ public abstract class ObjectProxyCache<T,A> {
             this.proxyRef = proxyRef;
             this.next = next;
         }
-        
+
         @SuppressWarnings("unchecked")
         static final <T> Entry<T>[] newArray(int size) {
             return new Entry[size];
         }
      }
-    
+
     // lame generics issues: making Segment class static and manually
     // inserting cache reference to work around various problems generically
     // referencing methods/vars across classes.
@@ -308,7 +308,7 @@ public abstract class ObjectProxyCache<T,A> {
             entryTable = Entry.newArray(capacity);
             this.cache = cache;
         }
-        
+
         // must be called under lock
         private void expunge() {
             Entry<T>[] table = entryTable;
@@ -327,7 +327,7 @@ public abstract class ObjectProxyCache<T,A> {
                 }
             }
         }
-        
+
         // must be called under lock
         private void remove(Entry<T>[] table, int hash, Entry<T> e) {
             int index = hash & (table.length - 1);
@@ -476,7 +476,7 @@ public abstract class ObjectProxyCache<T,A> {
                 unlock();
             }
         }
-        
+
         T get(Object object, int hash) {
             Entry<T>[] table;
             for (Entry<T> e = (table = entryTable)[hash & table.length - 1]; e != null; e = e.next) {
