@@ -1,9 +1,9 @@
 /*
  ***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -710,7 +710,9 @@ public final class ThreadContext {
         RubyStackTraceElement[] fullTrace = getFullTrace(length, stacktrace);
 
         int traceLength = safeLength(level, length, fullTrace);
-        if (traceLength < 0) return nil;
+
+        // MRI started returning [] instead of nil some time after 1.9 (#4891)
+        if (traceLength < 0) return runtime.newEmptyArray();
 
         final RubyClass stringClass = runtime.getString();
         final IRubyObject[] traceArray = new IRubyObject[traceLength];
@@ -738,7 +740,9 @@ public final class ThreadContext {
         RubyStackTraceElement[] fullTrace = getFullTrace(length, stacktrace);
 
         int traceLength = safeLength(level, length, fullTrace);
-        if (traceLength < 0) return nil;
+
+        // MRI started returning [] instead of nil some time after 1.9 (#4891)
+        if (traceLength < 0) return runtime.newEmptyArray();
 
         RubyArray backTrace = RubyThread.Location.newLocationArray(runtime, fullTrace, level, traceLength);
         if (RubyInstanceConfig.LOG_CALLERS) TraceType.logCaller(backTrace);
