@@ -1,8 +1,8 @@
 /***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -224,7 +224,7 @@ public class RegexpSupport {
         if (!needEscape) {
             to.append(bytes, start, len);
         } else {
-            boolean isUnicode = StringSupport.isUnicode(enc);
+            boolean isUnicode = enc.isUnicode();
             p = start;
             while (p < end) {
                 final int c;
@@ -469,7 +469,7 @@ public class RegexpSupport {
      * @param mode error mode
      */
     private static void appendUtf8(Ruby runtime, ByteList to, int code, Encoding[] enc, ByteList str, ErrorMode mode) {
-        checkUnicodeRange(runtime, code, str, mode);
+        checkUnicodeRange(runtime, code, str, ErrorMode.PREPROCESS);
 
         if (code < 0x80) {
             if (to != null) Sprintf.sprintf(runtime, to, "\\x%02X", code);
