@@ -1,9 +1,9 @@
 /*
  ***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -433,7 +433,7 @@ public class TypeConverter {
                 double value = ((RubyFloat)val).getValue();
                 if (value <= RubyFixnum.MAX ||
                         value >= RubyFixnum.MIN) {
-                    return RubyNumeric.dbl2num(context.runtime, value);
+                    return RubyNumeric.dbl2ival(context.runtime, value);
                 }
             } else if (val instanceof RubyFixnum || val instanceof RubyBignum) {
                 if (base != 0) raiseIntegerBaseError(context);
