@@ -1,6 +1,7 @@
 package org.jruby.util.io;
 
 import jnr.constants.platform.Errno;
+import jnr.constants.platform.Fcntl;
 import jnr.constants.platform.OpenFlags;
 import org.jcodings.Encoding;
 import org.jcodings.Ptr;
@@ -19,8 +20,10 @@ import org.jruby.RubyNumeric;
 import org.jruby.RubyString;
 import org.jruby.RubyThread;
 import org.jruby.exceptions.RaiseException;
+import org.jruby.ext.fcntl.FcntlLibrary;
 import org.jruby.platform.Platform;
 import org.jruby.runtime.Block;
+import org.jruby.runtime.Helpers;
 import org.jruby.runtime.ThreadContext;
 import org.jruby.runtime.builtin.IRubyObject;
 import org.jruby.util.ByteList;
@@ -39,8 +42,8 @@ import java.nio.channels.SelectionKey;
 import java.nio.channels.Selector;
 import java.nio.channels.SocketChannel;
 import java.nio.channels.WritableByteChannel;
-import java.util.ArrayList;
-import java.util.List;
+import java.util.HashSet;
+import java.util.Set;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
@@ -147,7 +150,7 @@ public class OpenFile implements Finalizable {
 
     private final Ruby runtime;
 
-    protected List<RubyThread> blockingThreads;
+    protected volatile Set<RubyThread> blockingThreads;
 
     public void clearStdio() {
         stdio_file = null;
@@ -835,6 +838,10 @@ public class OpenFile implements Finalizable {
     }
 
     public void finalize(ThreadContext context, boolean noraise) {
+        finalizeFlush(context, noraise);
+    }
+
+    public void finalizeFlush(ThreadContext context, boolean noraise) {
         IRubyObject err = runtime.getNil();
         ChannelFD fd = this.fd();
         Closeable stdio_file = this.stdio_file;
@@ -1399,6 +1406,12 @@ public class OpenFile implements Finalizable {
                 return false;
             }
 
+            if (posix.errno != null && posix.errno != Errno.EAGAIN
+                    && posix.errno != Errno.EWOULDBLOCK && posix.errno != Errno.EINTR) {
+                // Encountered a permanent error. Don't read again.
+                return false;
+            }
+
             if (fd.chSelect != null) {
                 unlock();
                 try {
@@ -1547,7 +1560,7 @@ public class OpenFile implements Finalizable {
     }
 
     // rb_io_getline_fast
-    public IRubyObject getlineFast(ThreadContext context, Encoding enc, RubyIO io) {
+    public IRubyObject getlineFast(ThreadContext context, Encoding enc, RubyIO io, boolean chomp) {
         Ruby runtime = context.runtime;
         IRubyObject str = null;
         ByteList strByteList;
@@ -1564,22 +1577,28 @@ public class OpenFile implements Finalizable {
                     byte[] pBytes = READ_DATA_PENDING_PTR();
                     int p = READ_DATA_PENDING_OFF();
                     int e;
+                    int chomplen = 0;
 
                     e = memchr(pBytes, p, '\n', pending);
                     if (e != -1) {
                         pending = (int) (e - p + 1);
+                        if (chomp) {
+                            chomplen = ((pending > 1 &&  pBytes[e - 1] == '\r')?1:0) + 1;
+                        }
                     }
                     if (str == null) {
-                        str = RubyString.newString(runtime, pBytes, p, pending);
+                        str = RubyString.newString(runtime, pBytes, p, pending - chomplen);
                         strByteList = ((RubyString) str).getByteList();
                         rbuf.off += pending;
                         rbuf.len -= pending;
                     } else {
-                        ((RubyString) str).resize(len + pending);
+                        ((RubyString) str).resize(len + pending - chomplen);
                         strByteList = ((RubyString) str).getByteList();
-                        readBufferedData(strByteList.unsafeBytes(), strByteList.begin() + len, pending);
+                        readBufferedData(strByteList.unsafeBytes(), strByteList.begin() + len, pending - chomplen);
+                        rbuf.off += chomplen;
+                        rbuf.len -= chomplen;
                     }
-                    len += pending;
+                    len += pending - chomplen;
                     if (cr != StringSupport.CR_BROKEN)
                         pos += StringSupport.codeRangeScanRestartable(enc, strByteList.unsafeBytes(), strByteList.begin() + pos, strByteList.begin() + len, cr);
                     if (e != -1) break;
@@ -2569,25 +2588,51 @@ public class OpenFile implements Finalizable {
 //            #endif
             if (ret == -1) return -1;
         }
-        // TODO?
-//        rb_maygvl_fd_fix_cloexec(ret);
+        fdFixCloexec(posix, ret);
         return ret;
     }
 
+    // MRI: rb_maygvl_fd_fix_cloexec, without compiler conditions
+    public static void fdFixCloexec(PosixShim posix, int fd) {
+        if (fd >= 0 && fd < FilenoUtil.FIRST_FAKE_FD) {
+            int flags, flags2, ret;
+            flags = posix.fcntlGetFD(fd); /* should not fail except EBADF. */
+            if (flags == -1) {
+                throw new RuntimeException(String.format("BUG: rb_maygvl_fd_fix_cloexec: fcntl(%d, F_GETFD) failed: %s", fd, posix.errno.description()));
+            }
+            if (fd <= 2)
+                flags2 = flags & ~FcntlLibrary.FD_CLOEXEC; /* Clear CLOEXEC for standard file descriptors: 0, 1, 2. */
+            else
+                flags2 = flags | FcntlLibrary.FD_CLOEXEC; /* Set CLOEXEC for non-standard file descriptors: 3, 4, 5, ... */
+            if (flags != flags2) {
+                ret = posix.fcntlSetFD(fd, flags2);
+                if (ret == -1) {
+                    throw new RuntimeException(String.format("BUG: rb_maygvl_fd_fix_cloexec: fcntl(%d, F_SETFD) failed: %s", fd, flags2, posix.errno.description()));
+                }
+            }
+        }
+        // otherwise JVM sets cloexec
+    }
+
     /**
      * Add a thread to the list of blocking threads for this IO.
      *
      * @param thread A thread blocking on this IO
      */
     public void addBlockingThread(RubyThread thread) {
-        boolean locked = lock();
-        try {
-            if (blockingThreads == null) {
-                blockingThreads = new ArrayList<RubyThread>(1);
+        Set<RubyThread> blockingThreads = this.blockingThreads;
+
+        if (blockingThreads == null) {
+            synchronized (this) {
+                blockingThreads = this.blockingThreads;
+                if (blockingThreads == null) {
+                    this.blockingThreads = blockingThreads = new HashSet<RubyThread>(1);
+                }
             }
+        }
+
+        synchronized (blockingThreads) {
             blockingThreads.add(thread);
-        } finally {
-            if (locked) unlock();
         }
     }
 
@@ -2596,40 +2641,58 @@ public class OpenFile implements Finalizable {
      *
      * @param thread A thread blocking on this IO
      */
-    public synchronized void removeBlockingThread(RubyThread thread) {
-        boolean locked = lock();
-        try {
-            if (blockingThreads == null) {
-                return;
-            }
-            for (int i = 0; i < blockingThreads.size(); i++) {
-                if (blockingThreads.get(i) == thread) {
-                    // not using remove(Object) here to avoid the equals() call
-                    blockingThreads.remove(i);
-                }
-            }
-        } finally {
-            if (locked) unlock();
+    public void removeBlockingThread(RubyThread thread) {
+        Set<RubyThread> blockingThreads = this.blockingThreads;
+
+        if (blockingThreads == null) {
+            return;
+        }
+
+        synchronized (blockingThreads) {
+            blockingThreads.remove(thread);
         }
     }
 
     /**
      * Fire an IOError in all threads blocking on this IO object
      */
-    public void interruptBlockingThreads() {
-        boolean locked = lock();
-        try {
-            if (blockingThreads == null) {
-                return;
-            }
-            for (int i = 0; i < blockingThreads.size(); i++) {
-                RubyThread thread = blockingThreads.get(i);
+    public void interruptBlockingThreads(ThreadContext context) {
+        Set<RubyThread> blockingThreads = this.blockingThreads;
+
+        if (blockingThreads == null) {
+            return;
+        }
+
+        synchronized (blockingThreads) {
+            for (RubyThread thread : blockingThreads) {
+                // If it's the current thread, ignore it since we're the one doing the interrupting
+                if (thread == context.getThread()) continue;
 
                 // raise will also wake the thread from selection
-                thread.raise(new IRubyObject[]{runtime.newIOError("stream closed").getException()}, Block.NULL_BLOCK);
+                RubyException exception = (RubyException) runtime.getIOError().newInstance(context, runtime.newString("stream closed"), Block.NULL_BLOCK);
+                thread.raise(Helpers.arrayOf(exception), Block.NULL_BLOCK);
+            }
+        }
+    }
+
+    /**
+     * Wait until all blocking threads have exited their blocking area. Use in combination with
+     * interruptBlockingThreads to ensure every blocking thread has moved on before proceding to
+     * manipulate the IO.
+     */
+    public void waitForBlockingThreads(ThreadContext context) {
+        Set<RubyThread> blockingThreads = this.blockingThreads;
+
+        if (blockingThreads == null) {
+            return;
+        }
+
+        while (blockingThreads.size() > 0) {
+            try {
+                context.getThread().sleep(1);
+            } catch (InterruptedException ie) {
+                break;
             }
-        } finally {
-            if (locked) unlock();
         }
     }
 
