@@ -405,6 +405,17 @@ public class PosixShim {
         return ret;
     }
 
+    public int fcntlSetFD(int fd, int flags) {
+        int ret = posix.fcntlInt(fd, Fcntl.F_SETFD, flags);
+        if (ret == -1) errno = Errno.valueOf(posix.errno());
+        return ret;
+    }
+
+    public int fcntlGetFD(int fd) {
+        int ret = posix.fcntl(fd, Fcntl.F_GETFD);
+        return ret;
+    }
+
     public Channel open(String cwd, String path, ModeFlags flags, int perm) {
         if ((path.equals("/dev/null") || path.equalsIgnoreCase("nul")) && Platform.IS_WINDOWS) {
             path = "NUL:";
@@ -416,6 +427,8 @@ public class PosixShim {
             errno = Errno.EEXIST;
         } catch (ResourceException.FileIsDirectory e) {
             errno = Errno.EISDIR;
+        } catch (ResourceException.FileIsNotDirectory e) {
+            errno = Errno.ENOTDIR;
         } catch (ResourceException.NotFound e) {
             errno = Errno.ENOENT;
         } catch (ResourceException.PermissionDenied e) {
@@ -423,7 +436,7 @@ public class PosixShim {
         } catch (ResourceException.TooManySymlinks e) {
             errno = Errno.ELOOP;
         } catch (IOException e) {
-            throw new RuntimeException("Unhandled IOException: " + e.getLocalizedMessage(), e);
+            errno = Helpers.errnoFromException(e);
         }
         return null;
     }
