@@ -1,9 +1,9 @@
 /*
  ***** BEGIN LICENSE BLOCK *****
- * Version: EPL 1.0/GPL 2.0/LGPL 2.1
+ * Version: EPL 2.0/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Eclipse Public
- * License Version 1.0 (the "License"); you may not use this file
+ * License Version 2.0 (the "License"); you may not use this file
  * except in compliance with the License. You may obtain a copy of
  * the License at http://www.eclipse.org/legal/epl-v10.html
  *
@@ -36,6 +36,7 @@ import org.jruby.RubyFixnum;
 import org.jruby.RubyHash;
 import org.jruby.RubySymbol;
 import org.jruby.exceptions.RaiseException;
+import org.jruby.runtime.builtin.IRubyObject;
 
 /**
  * @author chadfowler
@@ -194,4 +195,20 @@ public class TestRubyHash extends TestRubyBase {
     public void testDoubleQuotedUtf8HashKey() throws Exception {
         assertEquals("UTF-8", eval("# encoding: utf-8\n h = { \"Ãa1\": true }\n puts h.keys.first.encoding"));
     }
+
+    public void testPutExisting() {
+        Ruby ruby = Ruby.newInstance();
+        IRubyObject hash = ruby.evalScriptlet("{ \"Jane Doe\" => 10, \"Jim Doe\" => 6 }");
+        assertTrue(RubyHash.class.isInstance(hash));
+        RubyHash rubyHash = (RubyHash) hash;
+        assertEquals(10L, rubyHash.put("Jane Doe", 42));
+    }
+
+    public void testPutNotExisting() {
+        Ruby ruby = Ruby.newInstance();
+        IRubyObject hash = ruby.evalScriptlet("{ \"Jim Doe\" => 6 }");
+        assertTrue(RubyHash.class.isInstance(hash));
+        RubyHash rubyHash = (RubyHash) hash;
+        assertEquals(null, rubyHash.put("Jane Doe", 42));
+    }
 }
