@@ -15,6 +15,7 @@ require 'rubygems/basic_specification'
 require 'rubygems/stub_specification'
 require 'rubygems/util/list'
 require 'stringio'
+require 'uri'
 
 ##
 # The Specification class contains the information for a Gem.  Typically
@@ -157,20 +158,16 @@ class Gem::Specification < Gem::BasicSpecification
     :summary                   => nil,
     :test_files                => [],
     :version                   => nil,
-  }.freeze
+  }
 
-  INITIALIZE_CODE_FOR_DEFAULTS = { } # :nodoc:
+  Dupable = { } # :nodoc:
 
   @@default_value.each do |k,v|
-    INITIALIZE_CODE_FOR_DEFAULTS[k] = case v
-    when [], {}, true, false, nil, Numeric, Symbol
-      v.inspect
-    when String
-      v.dump
-    when Numeric
-       "default_value(:#{k})"
+    case v
+    when Time, Numeric, Symbol, true, false, nil
+      Dupable[k] = false
     else
-       "default_value(:#{k}).dup"
+      Dupable[k] = true
     end
   end
 
@@ -398,6 +395,8 @@ class Gem::Specification < Gem::BasicSpecification
   attr_reader :description
 
   ##
+  # :category: Recommended gemspec attributes
+  #
   # A contact email address (or addresses) for this gem
   #
   # Usage:
@@ -457,23 +456,9 @@ class Gem::Specification < Gem::BasicSpecification
   #   bytes
   # * All strings must be UTF-8, no binary data is allowed
   #
-  # You can use metadata to specify links to your gem's homepage, codebase,
-  # documentation, wiki, mailing list, issue tracker and changelog.
+  # To add metadata for the location of a issue tracker:
   #
-  #   s.metadata = {
-  #     "bug_tracker_uri"   => "https://example.com/user/bestgemever/issues",
-  #     "changelog_uri"     => "https://example.com/user/bestgemever/CHANGELOG.md",
-  #     "documentation_uri" => "https://www.example.info/gems/bestgemever/0.0.1",
-  #     "homepage_uri"      => "https://bestgemever.example.io",
-  #     "mailing_list_uri"  => "https://groups.example.com/bestgemever",
-  #     "source_code_uri"   => "https://example.com/user/bestgemever",
-  #     "wiki_uri"          => "https://example.com/user/bestgemever/wiki"
-  #   }
-  #
-  # These links will be used on your gem's page on rubygems.org and must pass
-  # validation against following regex.
-  #
-  #   %r{\Ahttps?:\/\/([^\s:@]+:[^\s:@]*@)?[A-Za-z\d\-]+(\.[A-Za-z\d\-]+)+\.?(:\d{1,5})?([\/?]\S*)?\z}
+  #   s.metadata = { "issue_tracker" => "https://example/issues" }
 
   attr_accessor :metadata
 
@@ -489,7 +474,7 @@ class Gem::Specification < Gem::BasicSpecification
   # activated when a gem is required.
 
   def add_development_dependency(gem, *requirements)
-    add_dependency_with_type(gem, :development, requirements)
+    add_dependency_with_type(gem, :development, *requirements)
   end
 
   ##
@@ -500,7 +485,7 @@ class Gem::Specification < Gem::BasicSpecification
   #   spec.add_runtime_dependency 'example', '~> 1.1', '>= 1.1.4'
 
   def add_runtime_dependency(gem, *requirements)
-    add_dependency_with_type(gem, :runtime, requirements)
+    add_dependency_with_type(gem, :runtime, *requirements)
   end
 
   ##
@@ -898,7 +883,7 @@ class Gem::Specification < Gem::BasicSpecification
   # properly sorted.
 
   def self.add_spec spec
-    warn "Gem::Specification.add_spec is deprecated and will be removed in RubyGems 3.0" unless Gem::Deprecate.skip
+    warn "Gem::Specification.add_spec is deprecated and will be removed in Rubygems 3.0" unless Gem::Deprecate.skip
     # TODO: find all extraneous adds
     # puts
     # p :add_spec => [spec.full_name, caller.reject { |s| s =~ /minitest/ }]
@@ -923,7 +908,7 @@ class Gem::Specification < Gem::BasicSpecification
   # Adds multiple specs to the known specifications.
 
   def self.add_specs *specs
-    warn "Gem::Specification.add_specs is deprecated and will be removed in RubyGems 3.0" unless Gem::Deprecate.skip
+    warn "Gem::Specification.add_specs is deprecated and will be removed in Rubygems 3.0" unless Gem::Deprecate.skip
 
     raise "nil spec!" if specs.any?(&:nil?) # TODO: remove once we're happy
 
@@ -1034,13 +1019,6 @@ class Gem::Specification < Gem::BasicSpecification
     Gem::Dependency.new(name, *requirements).matching_specs
   end
 
-  ##
-  # Returns every spec that has the given +full_name+
-
-  def self.find_all_by_full_name(full_name)
-    stubs.select {|s| s.full_name == full_name }.map(&:to_spec)
-  end
-
   ##
   # Find the best specification matching a +name+ and +requirements+. Raises
   # if the dependency doesn't resolve to a valid specification.
@@ -1059,7 +1037,6 @@ class Gem::Specification < Gem::BasicSpecification
   def self.find_by_path path
     path = path.dup.freeze
     spec = @@spec_with_requirable_file[path] ||= (stubs.find { |s|
-      next unless Gem::BundlerVersionFinder.compatible?(s)
       s.contains_requirable_file? path
     } || NOT_FOUND)
     spec.to_spec
@@ -1071,9 +1048,7 @@ class Gem::Specification < Gem::BasicSpecification
 
   def self.find_inactive_by_path path
     stub = stubs.find { |s|
-      next if s.activated?
-      next unless Gem::BundlerVersionFinder.compatible?(s)
-      s.contains_requirable_file? path
+      s.contains_requirable_file? path unless s.activated?
     }
     stub && stub.to_spec
   end
@@ -1127,7 +1102,7 @@ class Gem::Specification < Gem::BasicSpecification
     Gem.load_yaml
 
     input = normalize_yaml_input input
-    spec = YAML.load input
+    spec = Gem::SafeYAML.safe_load input
 
     if spec && spec.class == FalseClass then
       raise Gem::EndOfYAMLException
@@ -1272,7 +1247,7 @@ class Gem::Specification < Gem::BasicSpecification
   # Removes +spec+ from the known specs.
 
   def self.remove_spec spec
-    warn "Gem::Specification.remove_spec is deprecated and will be removed in RubyGems 3.0" unless Gem::Deprecate.skip
+    warn "Gem::Specification.remove_spec is deprecated and will be removed in Rubygems 3.0" unless Gem::Deprecate.skip
     _all.delete spec
     stubs.delete_if { |s| s.full_name == spec.full_name }
     (@@stubs_by_name[spec.name] || []).delete_if { |s| s.full_name == spec.full_name }
@@ -1542,7 +1517,7 @@ class Gem::Specification < Gem::BasicSpecification
   # +requirements+.  Valid types are currently <tt>:runtime</tt> and
   # <tt>:development</tt>.
 
-  def add_dependency_with_type(dependency, type, requirements)
+  def add_dependency_with_type(dependency, type, *requirements)
     requirements = if requirements.empty? then
                      Gem::Requirement.default
                    else
@@ -2048,20 +2023,6 @@ class Gem::Specification < Gem::BasicSpecification
     yaml_initialize coder.tag, coder.map
   end
 
-
-
-  eval <<-RB, binding, __FILE__, __LINE__ + 1
-    def set_nil_attributes_to_nil
-      #{@@nil_attributes.map {|key| "@#{key} = nil" }.join "; "}
-    end
-    private :set_nil_attributes_to_nil
-
-    def set_not_nil_attributes_to_default_values
-      #{@@non_nil_attributes.map {|key| "@#{key} = #{INITIALIZE_CODE_FOR_DEFAULTS[key]}" }.join ";"}
-    end
-    private :set_not_nil_attributes_to_default_values
-  RB
-
   ##
   # Specification constructor. Assigns the default values to the attributes
   # and yields itself for further initialization.  Optionally takes +name+ and
@@ -2077,8 +2038,15 @@ class Gem::Specification < Gem::BasicSpecification
     @original_platform = nil
     @installed_by_version = nil
 
-    set_nil_attributes_to_nil
-    set_not_nil_attributes_to_default_values
+    @@nil_attributes.each do |key|
+      instance_variable_set "@#{key}", nil
+    end
+
+    @@non_nil_attributes.each do |key|
+      default = default_value(key)
+      value = Dupable[key] ? default.dup : default
+      instance_variable_set "@#{key}", value
+    end
 
     @new_platform = Gem::Platform::RUBY
 
@@ -2775,7 +2743,29 @@ class Gem::Specification < Gem::BasicSpecification
               'metadata must be a hash'
     end
 
-    validate_metadata
+    metadata.keys.each do |k|
+      if !k.kind_of?(String)
+        raise Gem::InvalidSpecificationException,
+                'metadata keys must be a String'
+      end
+
+      if k.size > 128
+        raise Gem::InvalidSpecificationException,
+                "metadata key too large (#{k.size} > 128)"
+      end
+    end
+
+    metadata.values.each do |k|
+      if !k.kind_of?(String)
+        raise Gem::InvalidSpecificationException,
+                'metadata values must be a String'
+      end
+
+      if k.size > 1024
+        raise Gem::InvalidSpecificationException,
+                "metadata value too large (#{k.size} > 1024)"
+      end
+    end
 
     licenses.each { |license|
       if license.length > 64
@@ -2821,15 +2811,21 @@ http://spdx.org/licenses or '#{Gem::Licenses::NONSTANDARD}' for a nonstandard li
       raise Gem::InvalidSpecificationException, "#{lazy} is not a summary"
     end
 
-    if homepage and not homepage.empty? and
-       homepage !~ /\A[a-z][a-z\d+.-]*:/i then
-      raise Gem::InvalidSpecificationException,
-            "\"#{homepage}\" is not a URI"
+    # Make sure a homepage is valid HTTP/HTTPS URI
+    if homepage and not homepage.empty?
+      begin
+        homepage_uri = URI.parse(homepage)
+        unless [URI::HTTP, URI::HTTPS].member? homepage_uri.class
+          raise Gem::InvalidSpecificationException, "\"#{homepage}\" is not a valid HTTP URI"
+        end
+      rescue URI::InvalidURIError
+        raise Gem::InvalidSpecificationException, "\"#{homepage}\" is not a valid HTTP URI"
+      end
     end
 
     # Warnings
 
-    %w[author homepage summary files].each do |attribute|
+    %w[author email homepage summary].each do |attribute|
       value = self.send attribute
       warning "no #{attribute} specified" if value.nil? or value.empty?
     end
@@ -2862,48 +2858,6 @@ http://spdx.org/licenses or '#{Gem::Licenses::NONSTANDARD}' for a nonstandard li
     end
   end
 
-  def validate_metadata
-    url_validation_regex = %r{\Ahttps?:\/\/([^\s:@]+:[^\s:@]*@)?[A-Za-z\d\-]+(\.[A-Za-z\d\-]+)+\.?(:\d{1,5})?([\/?]\S*)?\z}
-    link_keys = %w(
-      bug_tracker_uri
-      changelog_uri
-      documentation_uri
-      homepage_uri
-      mailing_list_uri
-      source_code_uri
-      wiki_uri
-    )
-
-    metadata.each do|key, value|
-      if !key.kind_of?(String)
-        raise Gem::InvalidSpecificationException,
-                "metadata keys must be a String"
-      end
-
-      if key.size > 128
-        raise Gem::InvalidSpecificationException,
-                "metadata key too large (#{key.size} > 128)"
-      end
-
-      if !value.kind_of?(String)
-        raise Gem::InvalidSpecificationException,
-                "metadata values must be a String"
-      end
-
-      if value.size > 1024
-        raise Gem::InvalidSpecificationException,
-                "metadata value too large (#{value.size} > 1024)"
-      end
-
-      if link_keys.include? key
-        if value !~ url_validation_regex
-          raise Gem::InvalidSpecificationException,
-                 "metadata['#{key}'] has invalid link: #{value.inspect}"
-        end
-      end
-    end
-  end
-
   ##
   # Checks that dependencies use requirements as we recommend.  Warnings are
   # issued when dependencies are open-ended or overly strict for semantic
