@@ -9,7 +9,7 @@ end
 =begin
 import org.jruby.Ruby;
 import org.jruby.RubyObject;
-import org.jruby.javasupport.util.RuntimeHelpers;
+import org.jruby.runtime.Helpers;
 import org.jruby.runtime.builtin.IRubyObject;
 import org.jruby.javasupport.JavaUtil;
 import org.jruby.RubyClass;
@@ -20,7 +20,7 @@ public class DeprecatedClass extends RubyObject  {
   private static final Ruby __ruby__ = Ruby.getGlobalRuntime();
   private static final RubyClass __metaclass__;
   static {
-    __ruby__.getLoadService().lockAndRequire("annotated.rb");
+    __ruby__.getLoadService().require("annotated.rb");
     RubyClass metaclass = __ruby__.getClass("DeprecatedClass");
     metaclass.setClassAllocator(DeprecatedClass.class);
     if (metaclass == null) throw new NoClassDefFoundError("Could not load Ruby class: DeprecatedClass");
@@ -30,4 +30,4 @@ public class DeprecatedClass extends RubyObject  {
     super(__ruby__, __metaclass__);
   }
 }
-=end
\ No newline at end of file
+=end
