@@ -4,16 +4,21 @@ require 'rake'
 def import(*args); java_import(*args); end
 require 'ant/rake'
 
-describe Ant, "Rake helpers", :type => :ant do
+describe Ant, "Rake helpers" do
+  include Ant::RSpec::AntExampleGroup
+
   it "should set FileLists as task attributes by joining them with commas" do
     ant = Ant.new
     ant.property :name => "files", :value => FileList['*.*']
-    ant.properties["files"].should =~ /,/
+    expect(ant.properties["files"]).to match(/,/)
   end
 
 end
 
-describe Ant, "Rake #ant_task", :type => :ant do
+describe Ant, "Rake #ant_task" do
+  include Ant::RSpec::AntExampleGroup
+  include Rake::DSL if defined?(Rake::DSL)
+
   before :each do
     @app = Rake.application
     Rake.application = Rake::Application.new
@@ -24,16 +29,16 @@ describe Ant, "Rake #ant_task", :type => :ant do
   end
 
   it "should create a Rake task whose body defines Ant tasks" do
-    ant.properties.should_not include("foo")
+    expect(ant.properties).not_to include("foo")
 
     task :initial
     ant_task :ant => :initial do
       property :name => "foo", :value => "bar"
     end
-    Rake::Task[:ant].should_not be_nil
-    Rake::Task[:ant].prerequisites.should == ["initial"]
+    expect(Rake::Task[:ant]).not_to be_nil
+    expect(Rake::Task[:ant].prerequisites).to contain_exactly("initial")
     Rake::Task[:ant].invoke
 
-    ant.properties["foo"].should == "bar"
+    expect(ant.properties["foo"]).to eq("bar")
   end
 end
