@@ -8,17 +8,17 @@ java_import "java_integration.fixtures.PackageField"
 
 describe "A JavaClass" do
   it "should provide a look up for fields using a Java formatted name" do
-    PrivateField.java_class.declared_field(:strField).should_not == nil
-    ProtectedField.java_class.declared_field(:strField).should_not == nil
-    PublicField.java_class.declared_field(:strField).should_not == nil
-    PackageField.java_class.declared_field(:strField).should_not == nil
+    expect(PrivateField.java_class.declared_field(:strField)).not_to eq(nil)
+    expect(ProtectedField.java_class.declared_field(:strField)).not_to eq(nil)
+    expect(PublicField.java_class.declared_field(:strField)).not_to eq(nil)
+    expect(PackageField.java_class.declared_field(:strField)).not_to eq(nil)
   end
 
   it "should provide a look up for a fields using a Ruby formatted name" do
-    PrivateField.java_class.declared_field(:str_field).should_not == nil
-    ProtectedField.java_class.declared_field(:str_field).should_not == nil
-    PublicField.java_class.declared_field(:str_field).should_not == nil
-    PackageField.java_class.declared_field(:str_field).should_not == nil
+    expect(PrivateField.java_class.declared_field(:str_field)).not_to eq(nil)
+    expect(ProtectedField.java_class.declared_field(:str_field)).not_to eq(nil)
+    expect(PublicField.java_class.declared_field(:str_field)).not_to eq(nil)
+    expect(PackageField.java_class.declared_field(:str_field)).not_to eq(nil)
   end
 end
 
@@ -32,21 +32,21 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj.java_object, "42" }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42" }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj.java_object, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil.to_java }.not_to raise_error
       end
 
       it "should get Ruby values" do 
         @field.set_value @obj.java_object, "42"
-        @field.value(@obj.java_object).should == "42"
+        expect(@field.value(@obj.java_object)).to eq("42")
 
         @field.set_value @obj.java_object, nil
-        @field.value(@obj.java_object).should be_nil
+        expect(@field.value(@obj.java_object)).to be_nil
       end
     end
     
@@ -58,21 +58,21 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj.java_object, "42" }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42" }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj.java_object, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil.to_java }.not_to raise_error
       end
 
       it "should get Ruby values" do 
         @field.set_value @obj.java_object, "42"
-        @field.value(@obj.java_object).should == "42"
+        expect(@field.value(@obj.java_object)).to eq("42")
 
         @field.set_value @obj.java_object, nil
-        @field.value(@obj.java_object).should be_nil
+        expect(@field.value(@obj.java_object)).to be_nil
       end
     end
     
@@ -83,22 +83,22 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj.java_object, "42" }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42" }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj.java_object, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil.to_java }.not_to raise_error
       end
 
 
       it "should get Ruby values" do 
         @field.set_value @obj.java_object, "42"
-        @field.value(@obj.java_object).should == "42"
+        expect(@field.value(@obj.java_object)).to eq("42")
 
         @field.set_value @obj.java_object, nil
-        @field.value(@obj.java_object).should be_nil
+        expect(@field.value(@obj.java_object)).to be_nil
       end
     end
     
@@ -110,21 +110,21 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj.java_object, "42" }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42" }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj.java_object, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj.java_object, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj.java_object, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj.java_object, nil.to_java }.not_to raise_error
       end
 
       it "should get Ruby values" do 
         @field.set_value @obj.java_object, "42"
-        @field.value(@obj.java_object).should == "42"
+        expect(@field.value(@obj.java_object)).to eq("42")
 
         @field.set_value @obj.java_object, nil
-        @field.value(@obj.java_object).should be_nil
+        expect(@field.value(@obj.java_object)).to be_nil
       end
     end
   end
@@ -138,21 +138,21 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj, "42" }.should_not raise_error
-        lambda { @field.set_value @obj, nil }.should_not raise_error
+        expect { @field.set_value @obj, "42" }.not_to raise_error
+        expect { @field.set_value @obj, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj, nil.to_java }.not_to raise_error
       end
 
       it "should get Ruby values" do 
         @field.set_value @obj, "42"
-        @field.value(@obj).should == "42"
+        expect(@field.value(@obj)).to eq("42")
 
         @field.set_value @obj, nil
-        @field.value(@obj).should be_nil
+        expect(@field.value(@obj)).to be_nil
       end
     end
     
@@ -164,21 +164,21 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj, "42" }.should_not raise_error
-        lambda { @field.set_value @obj, nil }.should_not raise_error
+        expect { @field.set_value @obj, "42" }.not_to raise_error
+        expect { @field.set_value @obj, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj, nil.to_java }.not_to raise_error
       end
 
       it "should get Ruby values" do 
         @field.set_value @obj, "42"
-        @field.value(@obj).should == "42"
+        expect(@field.value(@obj)).to eq("42")
 
         @field.set_value @obj, nil
-        @field.value(@obj).should be_nil
+        expect(@field.value(@obj)).to be_nil
       end
     end
     
@@ -189,21 +189,21 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj, "42" }.should_not raise_error
-        lambda { @field.set_value @obj, nil }.should_not raise_error
+        expect { @field.set_value @obj, "42" }.not_to raise_error
+        expect { @field.set_value @obj, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj, nil.to_java }.not_to raise_error
       end
 
       it "should get Ruby values" do 
         @field.set_value @obj, "42"
-        @field.value(@obj).should == "42"
+        expect(@field.value(@obj)).to eq("42")
 
         @field.set_value @obj, nil
-        @field.value(@obj).should be_nil
+        expect(@field.value(@obj)).to be_nil
       end
     end
     
@@ -215,21 +215,21 @@ describe "A JavaField" do
       end
 
       it "should set Ruby values" do
-        lambda { @field.set_value @obj, "42" }.should_not raise_error
-        lambda { @field.set_value @obj, nil }.should_not raise_error
+        expect { @field.set_value @obj, "42" }.not_to raise_error
+        expect { @field.set_value @obj, nil }.not_to raise_error
       end
 
       it "should set Java values" do
-        lambda { @field.set_value @obj, "42".to_java }.should_not raise_error
-        lambda { @field.set_value @obj, nil.to_java }.should_not raise_error
+        expect { @field.set_value @obj, "42".to_java }.not_to raise_error
+        expect { @field.set_value @obj, nil.to_java }.not_to raise_error
       end
 
       it "should get Ruby values" do 
         @field.set_value @obj, "42"
-        @field.value(@obj).should == "42"
+        expect(@field.value(@obj)).to eq("42")
 
         @field.set_value @obj, nil
-        @field.value(@obj).should be_nil
+        expect(@field.value(@obj)).to be_nil
       end
     end
   end
