@@ -4,17 +4,17 @@ require 'jruby'
 describe "The JRuby module" do
   it "should give access to a Java reference with the reference method" do
     str_ref = JRuby.reference("foo")
-    str_ref.class.should == org.jruby.RubyString
+    expect(str_ref.class).to eq(org.jruby.RubyString)
     
     str = str_ref.toString
-    str.class.should == String
+    expect(str.class).to eq(String)
   end
   
   it "should unwrap Java-wrapped Ruby objects with the dereference method" do
     io_ref = org.jruby.RubyIO.new(JRuby.runtime, java.lang.System.in)
-    io_ref.class.should == org.jruby.RubyIO
+    expect(io_ref.class).to eq(org.jruby.RubyIO)
     
     io = JRuby.dereference(io_ref)
-    io.class.should == IO
+    expect(io.class).to eq(IO)
   end
 end
