@@ -2,7 +2,7 @@ require 'mspec/guards/guard'
 
 class BlockDeviceGuard < SpecGuard
   def match?
-    platform_is_not :freebsd, :windows do
+    platform_is_not :freebsd, :windows, :opal do
       block = `find /dev /devices -type b 2> /dev/null`
       return !(block.nil? || block.empty?)
     end
@@ -12,11 +12,7 @@ class BlockDeviceGuard < SpecGuard
 end
 
 class Object
-  def with_block_device
-    g = BlockDeviceGuard.new
-    g.name = :with_block_device
-    yield if g.yield?
-  ensure
-    g.unregister
+  def with_block_device(&block)
+    BlockDeviceGuard.new.run_if(:with_block_device, &block)
   end
 end
