@@ -3,15 +3,15 @@
 # should clean up any temporary files created so that the temp
 # directory is empty when the process exits.
 
-SPEC_TEMP_DIR = "#{File.expand_path(Dir.pwd)}/rubyspec_temp"
+SPEC_TEMP_DIR = File.expand_path(ENV["SPEC_TEMP_DIR"] || "rubyspec_temp")
 
 SPEC_TEMP_UNIQUIFIER = "0"
 
-SPEC_TMEM_DIR_PID = Process.pid
+SPEC_TEMP_DIR_PID = Process.pid
 
 at_exit do
   begin
-    if SPEC_TMEM_DIR_PID == Process.pid
+    if SPEC_TEMP_DIR_PID == Process.pid
       Dir.delete SPEC_TEMP_DIR if File.directory? SPEC_TEMP_DIR
     end
   rescue SystemCallError
@@ -32,7 +32,7 @@ end
 
 class Object
   def tmp(name, uniquify=true)
-    Dir.mkdir SPEC_TEMP_DIR unless File.exists? SPEC_TEMP_DIR
+    Dir.mkdir SPEC_TEMP_DIR unless Dir.exist? SPEC_TEMP_DIR
 
     if uniquify and !name.empty?
       slash = name.rindex "/"
