@@ -1,4 +1,4 @@
-describe :array_index, :shared => true do
+describe :array_index, shared: true do
   it "returns the index of the first element == to object" do
     x = mock('3')
     def x.==(obj) 3 == obj; end
@@ -19,19 +19,19 @@ describe :array_index, :shared => true do
     [2, 1, 1, 1, 1].send(@method, 3).should == nil
   end
 
-  ruby_version_is "1.8.7" do
-    it "accepts a block instead of an argument" do
-      [4, 2, 1, 5, 1, 3].send(@method) {|x| x < 2}.should == 2
-    end
+  it "accepts a block instead of an argument" do
+    [4, 2, 1, 5, 1, 3].send(@method) {|x| x < 2}.should == 2
+  end
 
-    it "ignore the block if there is an argument" do
+  it "ignores the block if there is an argument" do
+    -> {
       [4, 2, 1, 5, 1, 3].send(@method, 5) {|x| x < 2}.should == 3
-    end
+    }.should complain(/given block not used/)
+  end
 
-    describe "given no argument and no block" do
-      it "produces an Enumerator" do
-        [].send(@method).should be_an_instance_of(enumerator_class)
-      end
+  describe "given no argument and no block" do
+    it "produces an Enumerator" do
+      [].send(@method).should be_an_instance_of(Enumerator)
     end
   end
-end
\ No newline at end of file
+end
