@@ -1,4 +1,6 @@
-describe :keep_if, :shared => true do
+require File.expand_path('../../../enumerable/shared/enumeratorized', __FILE__)
+
+describe :keep_if, shared: true do
   it "deletes elements for which the block returns a false value" do
     array = [1, 2, 3, 4, 5]
     array.send(@method) {|item| item > 3 }.should equal(array)
@@ -6,17 +8,31 @@ describe :keep_if, :shared => true do
   end
 
   it "returns an enumerator if no block is given" do
-    [1, 2, 3].send(@method).should be_an_instance_of(enumerator_class)
+    [1, 2, 3].send(@method).should be_an_instance_of(Enumerator)
   end
 
+  it "updates the receiver after all blocks" do
+    a = [1, 2, 3]
+    a.send(@method) do |e|
+      a.length.should == 3
+      false
+    end
+    a.length.should == 0
+  end
+
+  before :all do
+    @object = [1,2,3]
+  end
+  it_should_behave_like :enumeratorized_with_origin_size
+
   describe "on frozen objects" do
-    before(:each) do
+    before :each do
       @origin = [true, false]
       @frozen = @origin.dup.freeze
     end
 
     it "returns an Enumerator if no block is given" do
-      @frozen.send(@method).should be_an_instance_of(enumerator_class)
+      @frozen.send(@method).should be_an_instance_of(Enumerator)
     end
 
     describe "with truthy block" do
