@@ -1,5 +1,5 @@
-describe :bignum_divide, :shared => true do
-  before(:each) do
+describe :bignum_divide, shared: true do
+  before :each do
     @bignum = bignum_value(88)
   end
 
