@@ -1,5 +1,5 @@
-describe :bignum_equal, :shared => true do
-  before(:each) do
+describe :bignum_equal, shared: true do
+  before :each do
     @bignum = bignum_value
   end
 
