@@ -10,12 +10,10 @@ describe "ENV.to_a" do
     ENV.delete "foo"
   end
 
-  ruby_version_is "1.9" do
-    it "returns the entries in the locale encoding" do
-      ENV.to_a.each do |key, value|
-        key.encoding.should == Encoding.find('locale')
-        value.encoding.should == Encoding.find('locale')
-      end
+  it "returns the entries in the locale encoding" do
+    ENV.to_a.each do |key, value|
+      key.encoding.should == Encoding.find('locale')
+      value.encoding.should == Encoding.find('locale')
     end
   end
 end
