@@ -1,29 +1,22 @@
-module NoMethodErrorSpecs
-  class NoMethodErrorA; end
-
-  class NoMethodErrorB; end
-
-  class NoMethodErrorC;
-    protected
-    def a_protected_method;end
-    private
-    def a_private_method; end
-  end
-
-  class NoMethodErrorD; end
-end
-
 module ExceptionSpecs
   class Exceptional < Exception; end
 
   class Backtrace
     def self.backtrace
       begin
-        raise
+        raise # If you move this line, update backtrace_spec.rb
       rescue RuntimeError => e
         e.backtrace
       end
     end
+
+    def self.backtrace_locations
+      begin
+        raise
+      rescue RuntimeError => e
+        e.backtrace_locations
+      end
+    end
   end
 
   class UnExceptional < Exception
@@ -54,3 +47,26 @@ module ExceptionSpecs
     end
   end
 end
+
+module NoMethodErrorSpecs
+  class NoMethodErrorA; end
+
+  class NoMethodErrorB; end
+
+  class NoMethodErrorC;
+    protected
+    def a_protected_method;end
+    private
+    def a_private_method; end
+  end
+
+  class NoMethodErrorD; end
+end
+
+class NameErrorSpecs
+  class ReceiverClass
+    def call_undefined_class_variable
+      @@doesnt_exist
+    end
+  end
+end
