@@ -1,7 +1,7 @@
 require File.expand_path('../../../../spec_helper', __FILE__)
 
 ["APPEND", "CREAT", "EXCL", "FNM_CASEFOLD",
-  "FNM_DOTMATCH", "FNM_NOESCAPE", "FNM_PATHNAME",
+  "FNM_DOTMATCH", "FNM_EXTGLOB", "FNM_NOESCAPE", "FNM_PATHNAME",
   "FNM_SYSCASE", "LOCK_EX", "LOCK_NB", "LOCK_SH",
   "LOCK_UN", "NONBLOCK", "RDONLY",
   "RDWR", "TRUNC", "WRONLY"].each do |const|
