@@ -18,20 +18,10 @@ describe "Fixnum#divmod" do
     lambda { -10.divmod(0) }.should raise_error(ZeroDivisionError)
   end
 
-  ruby_version_is ""..."1.9" do
-    it "raises a FloatDomainError when the given argument is 0 and a Float" do
-      lambda { 0.divmod(0.0)   }.should raise_error(FloatDomainError)
-      lambda { 10.divmod(0.0)  }.should raise_error(FloatDomainError)
-      lambda { -10.divmod(0.0) }.should raise_error(FloatDomainError)
-    end
-  end
-
-  ruby_version_is "1.9" do
-    it "raises a ZeroDivisionError when the given argument is 0 and a Float" do
-      lambda { 0.divmod(0.0)   }.should raise_error(ZeroDivisionError)
-      lambda { 10.divmod(0.0)  }.should raise_error(ZeroDivisionError)
-      lambda { -10.divmod(0.0) }.should raise_error(ZeroDivisionError)
-    end
+  it "raises a ZeroDivisionError when the given argument is 0 and a Float" do
+    lambda { 0.divmod(0.0)   }.should raise_error(ZeroDivisionError)
+    lambda { 10.divmod(0.0)  }.should raise_error(ZeroDivisionError)
+    lambda { -10.divmod(0.0) }.should raise_error(ZeroDivisionError)
   end
 
   it "raises a TypeError when given a non-Integer" do
