@@ -5,7 +5,7 @@ describe "Hash#rehash" do
   it "reorganizes the hash by recomputing all key hash codes" do
     k1 = [1]
     k2 = [2]
-    h = new_hash
+    h = {}
     h[k1] = 0
     h[k2] = 1
 
@@ -25,7 +25,7 @@ describe "Hash#rehash" do
     v1.should_not_receive(:hash)
     v2.should_not_receive(:hash)
 
-    h = new_hash(k1 => v1, k2 => v2)
+    h = { k1 => v1, k2 => v2 }
 
     k1.should_receive(:hash).twice.and_return(0)
     k2.should_receive(:hash).twice.and_return(0)
@@ -35,17 +35,8 @@ describe "Hash#rehash" do
     h[k2].should == v2
   end
 
-  ruby_version_is ""..."1.9" do
-    it "raises a TypeError if called on a frozen instance" do
-      lambda { HashSpecs.frozen_hash.rehash  }.should raise_error(TypeError)
-      lambda { HashSpecs.empty_frozen_hash.rehash }.should raise_error(TypeError)
-    end
-  end
-
-  ruby_version_is "1.9" do
-    it "raises a RuntimeError if called on a frozen instance" do
-      lambda { HashSpecs.frozen_hash.rehash  }.should raise_error(RuntimeError)
-      lambda { HashSpecs.empty_frozen_hash.rehash }.should raise_error(RuntimeError)
-    end
+  it "raises a RuntimeError if called on a frozen instance" do
+    lambda { HashSpecs.frozen_hash.rehash  }.should raise_error(RuntimeError)
+    lambda { HashSpecs.empty_frozen_hash.rehash }.should raise_error(RuntimeError)
   end
 end
