@@ -5,12 +5,10 @@ require File.expand_path('../fixtures/classes', __FILE__)
 describe "Kernel#method" do
   it_behaves_like(:kernel_method, :method)
 
-  before(:each) do
+  before :each do
     @obj = KernelSpecs::A.new
   end
 
-  # The following examples are to clarify the difference between #method and
-  # #public_method on 1.9
   it "can be called on a private method" do
     @obj.send(:private_method).should == :private_method
     @obj.method(:private_method).should be_an_instance_of(Method)
@@ -31,12 +29,9 @@ describe "Kernel#method" do
     m.call.should == :defined
   end
 
-  ruby_version_is "1.9" do
-    it "can be called even if we only repond_to_missing? method, true" do
-      m = KernelSpecs::RespondViaMissing.new.method(:handled_privately)
-      m.should be_an_instance_of(Method)
-      m.call(1, 2, 3).should == "Done handled_privately([1, 2, 3])"
-    end
+  it "can be called even if we only repond_to_missing? method, true" do
+    m = KernelSpecs::RespondViaMissing.new.method(:handled_privately)
+    m.should be_an_instance_of(Method)
+    m.call(1, 2, 3).should == "Done handled_privately([1, 2, 3])"
   end
-
 end
