@@ -1,6 +1,6 @@
 require File.expand_path('../../../spec_helper', __FILE__)
 require File.expand_path('../fixtures/classes', __FILE__)
-require File.expand_path('../shared/send', __FILE__)
+require File.expand_path('../../../shared/basicobject/send', __FILE__)
 
 describe "Kernel#send" do
   it "invokes the named public method" do
@@ -14,10 +14,10 @@ describe "Kernel#send" do
 
   it "invokes the named alias of a public method" do
     class KernelSpecs::Foo
-      alias :aka :bar
       def bar
         'done'
       end
+      alias :aka :bar
     end
     KernelSpecs::Foo.new.send(:aka).should == 'done'
   end
@@ -44,25 +44,25 @@ describe "Kernel#send" do
 
   it "invokes the named alias of a private method" do
     class KernelSpecs::Foo
-      alias :aka :bar
       private
       def bar
         'done2'
       end
+      alias :aka :bar
     end
     KernelSpecs::Foo.new.send(:aka).should == 'done2'
   end
 
   it "invokes the named alias of a protected method" do
     class KernelSpecs::Foo
-      alias :aka :bar
       protected
       def bar
         'done2'
       end
+      alias :aka :bar
     end
     KernelSpecs::Foo.new.send(:aka).should == 'done2'
   end
 
-  it_behaves_like(:kernel_send, :send)
+  it_behaves_like(:basicobject_send, :send)
 end
