@@ -1,8 +1,6 @@
 require File.expand_path('../../../spec_helper', __FILE__)
 require File.expand_path('../shared/eql', __FILE__)
 
-ruby_version_is "1.9" do
-  describe "MatchData#eql?" do
-    it_behaves_like(:matchdata_eql, :eql?)
-  end
+describe "MatchData#eql?" do
+  it_behaves_like(:matchdata_eql, :eql?)
 end
