@@ -13,16 +13,8 @@ describe "Math.sinh" do
     Math.sinh(-2.8).should be_close(-8.19191835423591, TOLERANCE)
   end
 
-  ruby_version_is ""..."1.9" do
-    it "raises an ArgumentError if the argument cannot be coerced with Float()" do
-      lambda { Math.sinh("test") }.should raise_error(ArgumentError)
-    end
-  end
-
-  ruby_version_is "1.9" do
-    it "raises a TypeError if the argument cannot be coerced with Float()" do
-      lambda { Math.sinh("test") }.should raise_error(TypeError)
-    end
+  it "raises a TypeError if the argument cannot be coerced with Float()" do
+    lambda { Math.sinh("test") }.should raise_error(TypeError)
   end
 
   it "returns NaN given NaN" do
