@@ -18,16 +18,8 @@ describe "Math.tan" do
     Math.tan(-infinity_value).nan?.should == true
   end
 
-  ruby_version_is ""..."1.9" do
-    it "raises an ArgumentError if the argument cannot be coerced with Float()" do
-      lambda { Math.tan("test") }.should raise_error(ArgumentError)
-    end
-  end
-
-  ruby_version_is "1.9" do
-    it "raises a TypeError if the argument cannot be coerced with Float()" do
-      lambda { Math.tan("test") }.should raise_error(TypeError)
-    end
+  it "raises a TypeError if the argument cannot be coerced with Float()" do
+    lambda { Math.tan("test") }.should raise_error(TypeError)
   end
 
   it "returns NaN given NaN" do
