@@ -38,15 +38,7 @@ describe "Module#extended" do
     end
   end
 
-  ruby_version_is ""..."1.9" do
-    it "is private in its default implementation" do
-      Module.new.private_methods.should include("extended")
-    end
-  end
-
-  ruby_version_is "1.9" do
-    it "is private in its default implementation" do
-      Module.new.private_methods.should include(:extended)
-    end
+  it "is private in its default implementation" do
+    Module.new.private_methods.should include(:extended)
   end
 end
