@@ -1,8 +1,6 @@
 require File.expand_path('../../../spec_helper', __FILE__)
 require File.expand_path('../shared/equal', __FILE__)
 
-ruby_version_is "1.9"..."2.0" do
-  describe "Proc#eql?" do
-    it_behaves_like(:proc_equal, :eql?)
-  end
+describe "Proc#eql?" do
+  it_behaves_like(:proc_equal_undefined, :eql?)
 end
