@@ -22,12 +22,14 @@ describe "String#[] with Regexp, index" do
   it_behaves_like :string_slice_regexp_index, :[]
 end
 
-ruby_version_is "1.9" do
-  describe "String#[] with Regexp, group" do
-    it_behaves_like :string_slice_regexp_group, :[]
-  end
+describe "String#[] with Regexp, group" do
+  it_behaves_like :string_slice_regexp_group, :[]
 end
 
 describe "String#[] with String" do
   it_behaves_like :string_slice_string, :[]
 end
+
+describe "String#[] with Symbol" do
+  it_behaves_like :string_slice_symbol, :[]
+end
