@@ -1,6 +1,7 @@
 require File.expand_path('../../../spec_helper', __FILE__)
 require File.expand_path('../fixtures/classes', __FILE__)
 require File.expand_path('../shared/accessor', __FILE__)
+require File.expand_path('../../enumerable/shared/enumeratorized', __FILE__)
 
 describe "Struct#each" do
   it "passes each value to the given block" do
@@ -16,19 +17,11 @@ describe "Struct#each" do
     car.each {}.should == car
   end
 
-  ruby_version_is "" ... "1.8.7" do
-    it "fails if not passed a block" do
-      car = StructClasses::Car.new('Ford', 'Ranger')
-      lambda { car.each }.should raise_error(LocalJumpError)
-    end
+  it "returns an Enumerator if not passed a block" do
+    car = StructClasses::Car.new('Ford', 'Ranger')
+    car.each.should be_an_instance_of(Enumerator)
   end
 
-  ruby_version_is "1.8.7" do
-    it "returns an Enumerator if not passed a block" do
-      car = StructClasses::Car.new('Ford', 'Ranger')
-      car.each.should be_an_instance_of(enumerator_class)
-    end
-  end
-
-  it_behaves_like :struct_accessor, :length
+  it_behaves_like :struct_accessor, :each
+  it_behaves_like :enumeratorized_with_origin_size, :each, StructClasses::Car.new('Ford', 'Ranger')
 end
