@@ -3,7 +3,7 @@ require 'bigdecimal'
 
 describe "BigDecimal#+" do
 
-  before(:each) do
+  before :each do
     @one = BigDecimal("1")
     @zero = BigDecimal("0")
     @two = BigDecimal("2")
@@ -19,7 +19,6 @@ describe "BigDecimal#+" do
   end
 
   it "returns a + b" do
-
     (@two + @one).should == @three
     (@one + @two).should == @three
     (@one + @one_minus).should == @zero
@@ -28,8 +27,6 @@ describe "BigDecimal#+" do
     (@frac_1 + @frac_2).should == BigDecimal("1.9E-99999")
     (@frac_2 + @frac_1).should == BigDecimal("1.9E-99999")
     (@frac_1 + @frac_1).should == BigDecimal("2E-99999")
-# can't do it this way because * isn't implemented yet
-#    (@frac_1 + @frac_1).should == 2 * @frac_1
   end
 
   it "returns NaN if NaN is involved" do
