@@ -2,13 +2,13 @@ require File.expand_path('../../../../spec_helper', __FILE__)
 require 'cgi'
 
 describe "CGI::QueryExtension#[]" do
-  before(:each) do
+  before :each do
     ENV['REQUEST_METHOD'], @old_request_method = "GET", ENV['REQUEST_METHOD']
     ENV['QUERY_STRING'], @old_query_string = "one=a&two=b&two=c", ENV['QUERY_STRING']
     @cgi = CGI.new
   end
 
-  after(:each) do
+  after :each do
     ENV['REQUEST_METHOD'] = @old_request_method
     ENV['QUERY_STRING']   = @old_query_string
   end
@@ -24,11 +24,4 @@ describe "CGI::QueryExtension#[]" do
   it "returns a String" do
     @cgi["one"].should be_kind_of(String)
   end
-
-  ruby_version_is "" ... "1.9" do
-    it "sets the other values in the returned value" do
-      @cgi["one"].to_a.should == ["a"]
-      @cgi["two"].to_a.should == ["b", "c"]
-    end
-  end
 end
