@@ -2,12 +2,12 @@ require File.expand_path('../../../../spec_helper', __FILE__)
 require 'cgi'
 
 describe "CGI::QueryExtension#pragma" do
-  before(:each) do
+  before :each do
     ENV['REQUEST_METHOD'], @old_request_method = "GET", ENV['REQUEST_METHOD']
     @cgi = CGI.new
   end
 
-  after(:each) do
+  after :each do
     ENV['REQUEST_METHOD'] = @old_request_method
   end
 
