@@ -1,7 +1,7 @@
 require File.expand_path('../../fixtures/classes', __FILE__)
 require 'matrix'
 
-describe :collect, :shared => true do
+describe :collect, shared: true do
   before :all do
     @m = Matrix[ [1, 2], [1, 2] ]
   end
@@ -14,17 +14,13 @@ describe :collect, :shared => true do
     @m.send(@method) { |n| n * 2 }.should == Matrix[ [2, 4], [2, 4] ]
   end
 
-  ruby_bug "#1531", "1.8.7" do
-    it "returns an enumerator if no block is given" do
-      @m.send(@method).should be_an_instance_of(enumerator_class)
-    end
+  it "returns an enumerator if no block is given" do
+    @m.send(@method).should be_an_instance_of(Enumerator)
   end
 
-  ruby_bug "redmine #5307", "1.9.3" do
-    describe "for a subclass of Matrix" do
-      it "returns an instance of that subclass" do
-        MatrixSub.ins.send(@method){1}.should be_an_instance_of(MatrixSub)
-      end
+  describe "for a subclass of Matrix" do
+    it "returns an instance of that subclass" do
+      MatrixSub.ins.send(@method){1}.should be_an_instance_of(MatrixSub)
     end
   end
 end
