@@ -1,7 +1,7 @@
 require File.expand_path('../../fixtures/classes', __FILE__)
 require 'matrix'
 
-describe :matrix_conjugate, :shared => true do
+describe :matrix_conjugate, shared: true do
   it "returns a matrix with all entries 'conjugated'" do
     Matrix[ [1,   2], [3, 4] ].send(@method).should == Matrix[ [1,   2], [3, 4] ]
     Matrix[ [1.9, Complex(1,1)], [3, 4] ].send(@method).should == Matrix[ [1.9, Complex(1,-1)], [3, 4] ]
@@ -12,11 +12,9 @@ describe :matrix_conjugate, :shared => true do
     Matrix.empty(3, 0).send(@method).should == Matrix.empty(3, 0)
   end
 
-  ruby_bug "redmine #5307", "1.9.3" do
-    describe "for a subclass of Matrix" do
-      it "returns an instance of that subclass" do
-        MatrixSub.ins.send(@method).should be_an_instance_of(MatrixSub)
-      end
+  describe "for a subclass of Matrix" do
+    it "returns an instance of that subclass" do
+      MatrixSub.ins.send(@method).should be_an_instance_of(MatrixSub)
     end
   end
 end
