@@ -3,17 +3,18 @@ require 'net/http'
 require File.expand_path('../fixtures/http_server', __FILE__)
 
 describe "Net::HTTP.get_response" do
-  before(:all) do
+  before :each do
     NetHTTPSpecs.start_server
+    @port = NetHTTPSpecs.port
   end
 
-  after(:all) do
+  after :each do
     NetHTTPSpecs.stop_server
   end
 
   describe "when passed URI" do
     it "returns the response for the specified uri" do
-      res = Net::HTTP.get_response(URI.parse('http://localhost:3333/'))
+      res = Net::HTTP.get_response(URI.parse("http://localhost:#{@port}/"))
       res.content_type.should == "text/plain"
       res.body.should == "This is the index page."
     end
@@ -21,7 +22,7 @@ describe "Net::HTTP.get_response" do
 
   describe "when passed host, path, port" do
     it "returns the response for the specified host-path-combination" do
-      res = Net::HTTP.get_response('localhost', "/", 3333)
+      res = Net::HTTP.get_response('localhost', "/", @port)
       res.content_type.should == "text/plain"
       res.body.should == "This is the index page."
     end
