@@ -3,20 +3,14 @@ require 'net/http'
 require File.expand_path('../fixtures/http_server', __FILE__)
 
 describe "Net::HTTP#mkcol" do
-  before(:all) do
+  before :each do
     NetHTTPSpecs.start_server
+    @http = Net::HTTP.start("localhost", NetHTTPSpecs.port)
   end
 
-  after(:all) do
-    NetHTTPSpecs.stop_server
-  end
-
-  before(:each) do
-    @http = Net::HTTP.start("localhost", 3333)
-  end
-
-  after(:each) do
+  after :each do
     @http.finish if @http.started?
+    NetHTTPSpecs.stop_server
   end
 
   it "sends a MKCOL request to the passed path and returns the response" do
