@@ -1,9 +1,7 @@
-require File.expand_path('../../../spec_helper', __FILE__)
+require File.expand_path('../spec_helper', __FILE__)
 
-process_is_foreground do
+platform_is_not :darwin do
   with_feature :readline do
-    require 'readline'
-
     describe "Readline.vi_editing_mode" do
       it "returns nil" do
         Readline.vi_editing_mode.should be_nil
