@@ -5,12 +5,10 @@ require File.expand_path('../shared/add', __FILE__)
 describe "SortedSet#add" do
   it_behaves_like :sorted_set_add, :add
 
-  ruby_bug "redmine #118", "1.9.1" do
-    it "takes only values which responds <=>" do
-      obj = mock('no_comparison_operator')
-      obj.should_receive(:respond_to?).with(:<=>).and_return(false)
-      lambda { SortedSet["hello"].add(obj) }.should raise_error(ArgumentError)
-    end
+  it "takes only values which responds <=>" do
+    obj = mock('no_comparison_operator')
+    obj.should_receive(:respond_to?).with(:<=>).and_return(false)
+    lambda { SortedSet["hello"].add(obj) }.should raise_error(ArgumentError)
   end
 end
 
