@@ -14,7 +14,7 @@ describe "CApiWrappedStruct" do
     @s = CApiWrappedStructSpecs.new
   end
 
-  it "Data_Wrap_Struct should wrap and Data_Get_Struct should return data" do
+  it "wraps with Data_Wrap_Struct and Data_Get_Struct returns data" do
     a = @s.wrap_struct(1024)
     @s.get_struct(a).should == 1024
   end
@@ -24,15 +24,23 @@ describe "CApiWrappedStruct" do
     @s.get_struct(a).should == 1024
   end
 
+  describe "RDATA()" do
+    it "returns the struct data" do
+      a = @s.wrap_struct(1024)
+      @s.get_struct_rdata(a).should == 1024
+    end
 
-  it "RDATA()->data should return the struct data" do
-    a = @s.wrap_struct(1024)
-    @s.get_struct_rdata(a).should == 1024
+    it "allows changing the wrapped struct" do
+      a = @s.wrap_struct(1024)
+      @s.change_struct(a, 100)
+      @s.get_struct(a).should == 100
+    end
   end
 
-  it "Changing RDATA()->data should change the wrapped struct" do
-    a = @s.wrap_struct(1024)
-    @s.change_struct(a, 100)
-    @s.get_struct(a).should == 100
+  describe "DATA_PTR" do
+    it "returns the struct data" do
+      a = @s.wrap_struct(1024)
+      @s.get_struct_data_ptr(a).should == 1024
+    end
   end
 end
