@@ -1,49 +1,41 @@
 #ifndef RUBYSPEC_H
 #define RUBYSPEC_H
 
-/* Define convenience macros similar to the RubySpec guards to assist
+/* Define convenience macros similar to the mspec guards to assist
  * with version incompatibilities.
  */
 
-#include "rubyspec_version.h"
-
-#if RUBY_VERSION_MAJOR >= 2
-#define RUBY_VERSION_IS_2_0
+#include <ruby.h>
+#ifdef HAVE_RUBY_VERSION_H
+# include <ruby/version.h>
+#else
+# include <version.h>
 #endif
 
-#if defined(RUBY_VERSION_IS_2_0) || (RUBY_VERSION_MINOR == 9 && RUBY_VERSION_TEENY >= 3)
-#define RUBY_VERSION_IS_1_9_3
+#ifndef RUBY_VERSION_MAJOR
+#define RUBY_VERSION_MAJOR RUBY_API_VERSION_MAJOR
+#define RUBY_VERSION_MINOR RUBY_API_VERSION_MINOR
+#define RUBY_VERSION_TEENY RUBY_API_VERSION_TEENY
 #endif
 
-#if defined(RUBY_VERSION_IS_2_0) || (RUBY_VERSION_MINOR == 9 && RUBY_VERSION_TEENY >= 2)
-#define RUBY_VERSION_IS_1_9_2
+#define RUBY_VERSION_BEFORE(major,minor,teeny) \
+  ((RUBY_VERSION_MAJOR < (major)) || \
+   (RUBY_VERSION_MAJOR == (major) && RUBY_VERSION_MINOR < (minor)) || \
+   (RUBY_VERSION_MAJOR == (major) && RUBY_VERSION_MINOR == (minor) && RUBY_VERSION_TEENY < (teeny)))
+
+#if RUBY_VERSION_MAJOR > 2 || (RUBY_VERSION_MAJOR == 2 && RUBY_VERSION_MINOR >= 4)
+#define RUBY_VERSION_IS_2_4
 #endif
 
-#if defined(RUBY_VERSION_IS_2_0) || RUBY_VERSION_MINOR == 9
-#define RUBY_VERSION_IS_1_9
+#if RUBY_VERSION_MAJOR > 2 || (RUBY_VERSION_MAJOR == 2 && RUBY_VERSION_MINOR >= 3)
+#define RUBY_VERSION_IS_2_3
 #endif
 
-#if RUBY_VERSION_MAJOR == 1 && RUBY_VERSION_MINOR == 8
-#define RUBY_VERSION_IS_1_8_EX_1_9
-#endif
-
-#if defined(RUBY_VERSION_IS_2_0) || RUBY_VERSION_MINOR >= 8
-#define RUBY_VERSION_IS_1_8
-#endif
-
-#if defined(RUBY_VERSION_IS_1_9) || (RUBY_VERSION_MINOR == 8 && RUBY_VERSION_TEENY >= 7)
-#define RUBY_VERSION_IS_1_8_7
-#endif
-
-#if RUBY_VERSION_MAJOR == 1 && RUBY_VERSION_MINOR == 8 && RUBY_VERSION_TEENY < 7
-#define RUBY_VERSION_IS_1_8_EX_1_8_7
-#endif
-
-
 /* Define all function flags */
 
 /* Array */
-#define HAVE_RARRAY                        1
+#define HAVE_RB_ARRAY                      1
+#define HAVE_RARRAY_AREF                   1
 #define HAVE_RARRAY_LEN                    1
 #define HAVE_RARRAY_PTR                    1
 #define HAVE_RB_ARY_AREF                   1
@@ -57,42 +49,49 @@
 #define HAVE_RB_ARY_JOIN                   1
 #define HAVE_RB_ARY_NEW                    1
 #define HAVE_RB_ARY_NEW2                   1
+#define HAVE_RB_ARY_NEW_CAPA               1
 #define HAVE_RB_ARY_NEW3                   1
+#define HAVE_RB_ARY_NEW_FROM_ARGS          1
 #define HAVE_RB_ARY_NEW4                   1
+#define HAVE_RB_ARY_NEW_FROM_VALUES        1
 #define HAVE_RB_ARY_POP                    1
 #define HAVE_RB_ARY_PUSH                   1
+#define HAVE_RB_ARY_CAT                    1
 #define HAVE_RB_ARY_REVERSE                1
+#define HAVE_RB_ARY_ROTATE                 1
 #define HAVE_RB_ARY_SHIFT                  1
 #define HAVE_RB_ARY_STORE                  1
 #define HAVE_RB_ARY_CONCAT                 1
+#define HAVE_RB_ARY_PLUS                   1
 #define HAVE_RB_ARY_TO_ARY                 1
+#define HAVE_RB_ARY_SUBSEQ                 1
 #define HAVE_RB_ARY_TO_S                   1
 #define HAVE_RB_ARY_UNSHIFT                1
 #define HAVE_RB_ASSOC_NEW                  1
-#define HAVE_RB_INSPECTING_P               1
-#define HAVE_RB_PROTECT_INSPECT            1
 
 #define HAVE_RB_EACH                       1
 #define HAVE_RB_ITERATE                    1
 #define HAVE_RB_MEM_CLEAR                  1
 
 /* Bignum */
-#define HAVE_RBIGNUM_NEGATIVE_P            1
-#define HAVE_RBIGNUM_POSITIVE_P            1
-#define HAVE_RBIGNUM_SIGN                  1
+#define HAVE_ABSINT_SIZE                   1
 #define HAVE_RB_BIG2DBL                    1
+#define HAVE_RB_DBL2BIG                    1
 #define HAVE_RB_BIG2LL                     1
 #define HAVE_RB_BIG2LONG                   1
 #define HAVE_RB_BIG2STR                    1
 #define HAVE_RB_BIG2ULONG                  1
+#define HAVE_RB_BIG_CMP                    1
+#define HAVE_RB_BIG_PACK                   1
 
 /* Class */
 #define HAVE_RB_CALL_SUPER                 1
 #define HAVE_RB_CLASS2NAME                 1
-#define HAVE_RB_CLASS_INHERITED            1
 #define HAVE_RB_CLASS_NAME                 1
 #define HAVE_RB_CLASS_NEW                  1
 #define HAVE_RB_CLASS_NEW_INSTANCE         1
+#define HAVE_RB_CLASS_PATH                 1
+#define HAVE_RB_CLASS_REAL                 1
 #define HAVE_RB_CVAR_DEFINED               1
 #define HAVE_RB_CVAR_GET                   1
 #define HAVE_RB_CVAR_SET                   1
@@ -103,15 +102,28 @@
 #define HAVE_RB_INCLUDE_MODULE             1
 #define HAVE_RB_PATH2CLASS                 1
 #define HAVE_RB_PATH_TO_CLASS              1
+#define HAVE_RB_CLASS_SUPERCLASS           1
+
+/* Complex */
+#define HAVE_RB_COMPLEX                    1
+#define HAVE_RB_COMPLEX1                   1
+#define HAVE_RB_COMPLEX2                   1
+#define HAVE_RB_COMPLEX_NEW                1
+#define HAVE_RB_COMPLEX_NEW1               1
+#define HAVE_RB_COMPLEX_NEW2               1
 
 /* Constants */
 #define HAVE_RB_CARRAY                     1
+#ifndef RUBY_INTEGER_UNIFICATION
 #define HAVE_RB_CBIGNUM                    1
+#endif
 #define HAVE_RB_CCLASS                     1
 #define HAVE_RB_CDATA                      1
 #define HAVE_RB_CFALSECLASS                1
 #define HAVE_RB_CFILE                      1
+#ifndef RUBY_INTEGER_UNIFICATION
 #define HAVE_RB_CFIXNUM                    1
+#endif
 #define HAVE_RB_CFLOAT                     1
 #define HAVE_RB_CHASH                      1
 #define HAVE_RB_CINTEGER                   1
@@ -128,6 +140,7 @@
 #define HAVE_RB_CSTRING                    1
 #define HAVE_RB_CSTRUCT                    1
 #define HAVE_RB_CSYMBOL                    1
+#define HAVE_RB_CTIME                      1
 #define HAVE_RB_CTHREAD                    1
 #define HAVE_RB_CTRUECLASS                 1
 #define HAVE_RB_CNUMERATOR                 1
@@ -163,13 +176,16 @@
 #define HAVE_RB_MENUMERABLE                1
 #define HAVE_RB_MERRNO                     1
 #define HAVE_RB_MKERNEL                    1
+#define HAVE_RB_CDIR                       1
 
 /* Data */
 #define HAVE_DATA_WRAP_STRUCT              1
 #define HAVE_RDATA                         1
 
+#define HAVE_TYPEDDATA_WRAP_STRUCT         1
+#define HAVE_RTYPEDDATA
+
 /* Encoding */
-#ifdef RUBY_VERSION_IS_1_9
 #define HAVE_ENCODING_GET                  1
 #define HAVE_ENCODING_SET                  1
 #define HAVE_ENC_CODERANGE_ASCIIONLY       1
@@ -191,6 +207,7 @@
 #define HAVE_RB_ENCDB_ALIAS                1
 #define HAVE_RB_ENC_ASSOCIATE              1
 #define HAVE_RB_ENC_ASSOCIATE_INDEX        1
+#define HAVE_RB_ENC_CODEPOINT_LEN          1
 #define HAVE_RB_ENC_COMPATIBLE             1
 #define HAVE_RB_ENC_COPY                   1
 #define HAVE_RB_ENC_FIND                   1
@@ -225,11 +242,8 @@
 #define HAVE_RSTRING_LENINT                1
 #define HAVE_TIMET2NUM                     1
 
-#ifdef RUBY_VERSION_IS_1_9_3
-#define HAVE_RB_CLASS_SUPERCLASS           1
-#endif
 #define HAVE_RB_LONG2INT                   1
-#endif
+#define HAVE_RB_INTERN3                    1
 
 #define HAVE_RB_ITER_BREAK                 1
 #define HAVE_RB_SOURCEFILE                 1
@@ -237,9 +251,7 @@
 #define HAVE_RB_METHOD_BOUNDP              1
 
 /* Enumerable */
-#ifdef RUBY_VERSION_IS_1_8_7
 #define HAVE_RB_ENUMERATORIZE              1
-#endif
 
 /* Exception */
 #define HAVE_RB_EXC_NEW                    1
@@ -250,15 +262,12 @@
 
 /* File */
 #define HAVE_RB_FILE_OPEN                  1
-#ifdef RUBY_VERSION_IS_1_9
 #define HAVE_RB_FILE_OPEN_STR              1
 #define HAVE_FILEPATHVALUE                 1
-#endif
 
 /* Float */
 #define HAVE_RB_FLOAT_NEW                  1
 #define HAVE_RB_RFLOAT                     1
-#define HAVE_RFLOAT                        1
 #define HAVE_RFLOAT_VALUE                  1
 
 /* Globals */
@@ -272,26 +281,40 @@
 #define HAVE_RB_RS                         1
 #define HAVE_RB_OUTPUT_RS                  1
 #define HAVE_RB_OUTPUT_FS                  1
-#define HAVE_RB_SET_KCODE                  1
+#define HAVE_RB_STDERR                     1
+#define HAVE_RB_STDIN                      1
+#define HAVE_RB_STDOUT                     1
+#define HAVE_RB_DEFOUT                     1
 
 #define HAVE_RB_LASTLINE_SET               1
 #define HAVE_RB_LASTLINE_GET               1
 
 /* Hash */
 #define HAVE_RB_HASH                       1
+#define HAVE_RB_HASH2                      1
+#define HAVE_RB_HASH_DUP                   1
+#define HAVE_RB_HASH_FREEZE                1
 #define HAVE_RB_HASH_AREF                  1
 #define HAVE_RB_HASH_ASET                  1
+#define HAVE_RB_HASH_CLEAR                 1
 #define HAVE_RB_HASH_DELETE                1
 #define HAVE_RB_HASH_DELETE_IF             1
 #define HAVE_RB_HASH_FOREACH               1
 #define HAVE_RB_HASH_LOOKUP                1
+#define HAVE_RB_HASH_LOOKUP2               1
 #define HAVE_RB_HASH_NEW                   1
+#define HAVE_RB_HASH_SET_IFNONE            1
 #define HAVE_RB_HASH_SIZE                  1
 
+/* Integer */
+#define HAVE_RB_INTEGER_PACK               1
+
 /* IO */
 #define HAVE_GET_OPEN_FILE                 1
 #define HAVE_RB_IO_ADDSTR                  1
+#define HAVE_RB_IO_CHECK_IO                1
 #define HAVE_RB_IO_CHECK_CLOSED            1
+#define HAVE_RB_IO_TAINT_CHECK             1
 #define HAVE_RB_IO_CHECK_READABLE          1
 #define HAVE_RB_IO_CHECK_WRITABLE          1
 #define HAVE_RB_IO_CLOSE                   1
@@ -306,6 +329,17 @@
 #define HAVE_RB_THREAD_FD_WRITABLE         1
 #define HAVE_RB_THREAD_WAIT_FD             1
 
+#define HAVE_RB_MUTEX_NEW                  1
+#define HAVE_RB_MUTEX_LOCKED_P             1
+#define HAVE_RB_MUTEX_TRYLOCK              1
+#define HAVE_RB_MUTEX_LOCK                 1
+#define HAVE_RB_MUTEX_UNLOCK               1
+#define HAVE_RB_MUTEX_SLEEP                1
+#define HAVE_RB_MUTEX_SYNCHRONIZE          1
+
+#define HAVE_RB_FD_FIX_CLOEXEC             1
+#define HAVE_RB_CLOEXEC_OPEN               1
+
 /* Kernel */
 #define HAVE_RB_BLOCK_GIVEN_P              1
 #define HAVE_RB_BLOCK_PROC                 1
@@ -320,20 +354,19 @@
 #define HAVE_RB_RESCUE2                    1
 #define HAVE_RB_SET_END_PROC               1
 #define HAVE_RB_SYS_FAIL                   1
-#ifdef RUBY_VERSION_IS_1_9_3
 #define HAVE_RB_SYSERR_FAIL                1
 #define HAVE_RB_MAKE_BACKTRACE             1
-#endif
 #define HAVE_RB_THROW                      1
 #define HAVE_RB_CATCH                      1
-#ifdef RUBY_VERSION_IS_1_9
 #define HAVE_RB_THROW_OBJ                  1
 #define HAVE_RB_CATCH_OBJ                  1
-#endif
 #define HAVE_RB_WARN                       1
 #define HAVE_RB_YIELD                      1
 #define HAVE_RB_YIELD_SPLAT                1
 #define HAVE_RB_YIELD_VALUES               1
+#define HAVE_RB_FUNCALL3                   1
+#define HAVE_RB_FUNCALL_WITH_BLOCK         1
+#define HAVE_RB_PROTECT                    1
 
 /* GC */
 #define HAVE_RB_GC_REGISTER_ADDRESS        1
@@ -353,12 +386,15 @@
 #define HAVE_RB_CONST_GET_FROM             1
 #define HAVE_RB_CONST_SET                  1
 #define HAVE_RB_DEFINE_ALIAS               1
+#define HAVE_RB_DEFINE_CLASS               1
 #define HAVE_RB_DEFINE_CLASS_UNDER         1
+#define HAVE_RB_DEFINE_CLASS_ID_UNDER      1
 #define HAVE_RB_DEFINE_CONST               1
 #define HAVE_RB_DEFINE_GLOBAL_CONST        1
 #define HAVE_RB_DEFINE_GLOBAL_FUNCTION     1
 #define HAVE_RB_DEFINE_METHOD              1
 #define HAVE_RB_DEFINE_MODULE_FUNCTION     1
+#define HAVE_RB_DEFINE_MODULE              1
 #define HAVE_RB_DEFINE_MODULE_UNDER        1
 #define HAVE_RB_DEFINE_PRIVATE_METHOD      1
 #define HAVE_RB_DEFINE_PROTECTED_METHOD    1
@@ -373,25 +409,34 @@
 #define HAVE_RB_INTEGER                    1
 #define HAVE_RB_LL2INUM                    1
 #define HAVE_RB_NUM2DBL                    1
+#if SIZEOF_INT < SIZEOF_LONG
+#define HAVE_RB_NUM2INT                    1
+#define HAVE_RB_NUM2UINT                   1
+#endif
 #define HAVE_RB_NUM2LONG                   1
+#define HAVE_RB_INT2NUM                    1
 #define HAVE_RB_NUM2ULONG                  1
 #define HAVE_RB_NUM_COERCE_BIN             1
 #define HAVE_RB_NUM_COERCE_CMP             1
 #define HAVE_RB_NUM_COERCE_RELOP           1
 #define HAVE_RB_NUM_ZERODIV                1
 
+/* Fixnum */
+#if SIZEOF_INT < SIZEOF_LONG
+#define HAVE_RB_FIX2UINT                   1
+#define HAVE_RB_FIX2INT                    1
+#endif
+
 /* Object */
 #define HAVE_OBJ_TAINT                     1
 #define HAVE_OBJ_TAINTED                   1
 #define HAVE_OBJ_INFECT                    1
 #define HAVE_RB_ANY_TO_S                   1
 #define HAVE_RB_ATTR_GET                   1
-#define HAVE_RB_OBJ_INSTANCE_VARIABLES	   1
+#define HAVE_RB_OBJ_INSTANCE_VARIABLES     1
 #define HAVE_RB_CHECK_ARRAY_TYPE           1
 #define HAVE_RB_CHECK_CONVERT_TYPE         1
-#ifdef RUBY_VERSION_IS_1_8_7
 #define HAVE_RB_CHECK_TO_INTEGER           1
-#endif
 #define HAVE_RB_CHECK_FROZEN               1
 #define HAVE_RB_CHECK_STRING_TYPE          1
 #define HAVE_RB_CLASS_OF                   1
@@ -417,6 +462,7 @@
 #define HAVE_RB_OBJ_IS_KIND_OF             1
 #define HAVE_RB_OBJ_TAINT                  1
 #define HAVE_RB_OBJ_METHOD                 1
+#define HAVE_RB_OBJ_METHOD_ARITY           1
 #define HAVE_RB_REQUIRE                    1
 #define HAVE_RB_RESPOND_TO                 1
 #define HAVE_RB_OBJ_RESPOND_TO             1
@@ -425,9 +471,7 @@
 #define HAVE_RB_TO_INT                     1
 #define HAVE_RTEST                         1
 #define HAVE_TYPE                          1
-#ifdef RUBY_VERSION_IS_1_9
 #define HAVE_RB_TYPE_P                     1
-#endif
 #define HAVE_BUILTIN_TYPE                  1
 
 /* Proc */
@@ -435,11 +479,17 @@
 
 /* Range */
 #define HAVE_RB_RANGE_NEW                  1
+#define HAVE_RB_RANGE_VALUES               1
 
 /* Rational */
 #define HAVE_RB_RATIONAL                   1
 #define HAVE_RB_RATIONAL1                  1
 #define HAVE_RB_RATIONAL2                  1
+#define HAVE_RB_RATIONAL_NEW               1
+#define HAVE_RB_RATIONAL_NEW1              1
+#define HAVE_RB_RATIONAL_NEW2              1
+#define HAVE_RB_RATIONAL_NUM               1
+#define HAVE_RB_RATIONAL_DEN               1
 
 /* Regexp */
 #define HAVE_RB_BACKREF_GET                1
@@ -449,14 +499,9 @@
 #define HAVE_RB_REG_OPTIONS                1
 #define HAVE_RB_REG_REGCOMP                1
 
-/* Safe */
-#define HAVE_RB_SAFE_LEVEL                 1
-#define HAVE_RB_SECURE                     1
-
 /* String */
 #define HAVE_RB_CSTR2INUM                  1
 #define HAVE_RB_CSTR_TO_INUM               1
-#define HAVE_RB_STR2CSTR                   1
 #define HAVE_RB_STR2INUM                   1
 #define HAVE_RB_STR_APPEND                 1
 #define HAVE_RB_STR_BUF_CAT                1
@@ -469,28 +514,26 @@
 #define HAVE_RB_STR_FLUSH                  1
 #define HAVE_RB_STR_FREEZE                 1
 #define HAVE_RB_STR_HASH                   1
+#define HAVE_RB_STR_UPDATE                 1
 #define HAVE_RB_STR_INSPECT                1
 #define HAVE_RB_STR_INTERN                 1
-#define HAVE_RB_STR_LEN                    1
 #define HAVE_RB_STR_NEW                    1
 #define HAVE_RB_STR_NEW2                   1
 #define HAVE_RB_STR_NEW3                   1
 #define HAVE_RB_STR_NEW4                   1
+#define HAVE_RB_STR_NEW5                   1
 #define HAVE_RB_STR_PLUS                   1
-#define HAVE_RB_STR_PTR                    1
-#define HAVE_RB_STR_PTR_READONLY           1
+#define HAVE_RB_STR_TIMES                  1
 #define HAVE_RB_STR_RESIZE                 1
 #define HAVE_RB_STR_SET_LEN                1
 #define HAVE_RB_STR_SPLIT                  1
 #define HAVE_RB_STR_SUBSTR                 1
 #define HAVE_RB_STR_TO_STR                 1
-#define HAVE_RSTRING                       1
 #define HAVE_RSTRING_LEN                   1
 #define HAVE_RSTRING_PTR                   1
-#define HAVE_STR2CSTR                      1
 #define HAVE_STRINGVALUE                   1
 
-#ifdef RUBY_VERSION_IS_1_9
+#define HAVE_RB_STR_FREE                   1
 #define HAVE_RB_SPRINTF                    1
 #define HAVE_RB_LOCALE_STR_NEW             1
 #define HAVE_RB_LOCALE_STR_NEW_CSTR        1
@@ -501,61 +544,70 @@
 #define HAVE_RB_STR_LENGTH                 1
 #define HAVE_RB_STR_EQUAL                  1
 #define HAVE_RB_STR_SUBSEQ                 1
-#endif
+#define HAVE_RB_VSPRINTF                   1
+#define HAVE_RB_STRING                     1
 
 /* Struct */
 #define HAVE_RB_STRUCT_AREF                1
 #define HAVE_RB_STRUCT_ASET                1
 #define HAVE_RB_STRUCT_DEFINE              1
+#define HAVE_RB_STRUCT_DEFINE_UNDER        1
 #define HAVE_RB_STRUCT_NEW                 1
 #define HAVE_RB_STRUCT_GETMEMBER           1
+#define HAVE_RB_STRUCT_S_MEMBERS           1
+#define HAVE_RB_STRUCT_MEMBERS             1
+#ifdef RUBY_VERSION_IS_2_4
+#define HAVE_RB_STRUCT_SIZE                1
+#endif
 
 /* Symbol */
 #define HAVE_RB_ID2NAME                    1
-#ifdef RUBY_VERSION_IS_1_9
 #define HAVE_RB_ID2STR                     1
-#endif
+#define HAVE_RB_INTERN_STR                 1
 #define HAVE_RB_INTERN                     1
 #define HAVE_RB_IS_CLASS_ID                1
 #define HAVE_RB_IS_CONST_ID                1
 #define HAVE_RB_IS_INSTANCE_ID             1
+#define HAVE_RB_SYM2STR                    1
 
 /* Thread */
 #define HAVE_RB_THREAD_ALONE               1
-#define HAVE_RB_THREAD_BLOCKING_REGION     1
+#define HAVE_RB_THREAD_CALL_WITHOUT_GVL    1
 #define HAVE_RB_THREAD_CURRENT             1
 #define HAVE_RB_THREAD_LOCAL_AREF          1
 #define HAVE_RB_THREAD_LOCAL_ASET          1
-#define HAVE_RB_THREAD_SELECT              1
 #define HAVE_RB_THREAD_WAIT_FOR            1
 #define HAVE_RB_THREAD_WAKEUP              1
 #define HAVE_RB_THREAD_CREATE              1
 
 /* Time */
 #define HAVE_RB_TIME_NEW                   1
-#ifdef RUBY_VERSION_IS_1_9
 #define HAVE_RB_TIME_NANO_NEW              1
+#define HAVE_RB_TIME_NUM_NEW               1
+#define HAVE_RB_TIME_INTERVAL              1
+#define HAVE_RB_TIME_TIMEVAL               1
+#define HAVE_RB_TIME_TIMESPEC              1
+#ifdef RUBY_VERSION_IS_2_3
+#define HAVE_RB_TIMESPEC_NOW               1
+#define HAVE_RB_TIME_TIMESPEC_NEW          1
 #endif
 
 /* Util */
 #define HAVE_RB_SCAN_ARGS                  1
-#define HAVE_RUBY_SETENV                   1
-#define HAVE_RUBY_STRDUP                   1
 
 /* Now, create the differential set. The format of the preprocessor directives
  * is significant. The alternative implementations should define RUBY because
  * some extensions depend on that. But only one alternative implementation
  * macro should be defined at a time. The conditional is structured so that if
- * no alternative implementation is defined then MRI is assumed and "mri.h"
- * will be included.
+ * no alternative implementation is defined then MRI is assumed.
  */
 
 #if defined(RUBINIUS)
 #include "rubinius.h"
 #elif defined(JRUBY)
 #include "jruby.h"
-#else /* MRI */
-#include "mri.h"
+#elif defined(TRUFFLERUBY)
+#include "truffleruby.h"
 #endif
 
 #endif
