@@ -1,6 +1,6 @@
 require File.expand_path('../../../spec_helper', __FILE__)
 
-describe :complex_image, :shared => true do
+describe :complex_image, shared: true do
   it "returns the imaginary part of self" do
     Complex(1, 0).send(@method).should == 0
     Complex(2, 1).send(@method).should == 1
