@@ -1,4 +1,4 @@
-describe :file_writable, :shared => true do
+describe :file_writable, shared: true do
   before :each do
     @file = tmp('i_exist')
   end
@@ -14,14 +14,12 @@ describe :file_writable, :shared => true do
     File.open(@file,'w') { @object.send(@method, @file).should == true }
   end
 
-  ruby_version_is "1.9" do
-    it "accepts an object that has a #to_path method" do
-      File.open(@file,'w') { @object.send(@method, mock_to_path(@file)).should == true }
-    end
+  it "accepts an object that has a #to_path method" do
+    File.open(@file,'w') { @object.send(@method, mock_to_path(@file)).should == true }
   end
 end
 
-describe :file_writable_missing, :shared => true do
+describe :file_writable_missing, shared: true do
   it "returns false if the file does not exist" do
     @object.send(@method, 'fake_file').should == false
   end
