@@ -1,5 +1,5 @@
 require File.expand_path('../../../spec_helper', __FILE__)
 
-describe :rational_fdiv, :shared => true do
+describe :rational_fdiv, shared: true do
   it "needs to be reviewed for spec completeness"
 end
