@@ -3,7 +3,6 @@ exclude :test_aset_error, "needs investigation"
 exclude :test_combination_with_callcc, "no callcc"
 exclude :test_count, "needs investigation"
 exclude :test_flatten_with_callcc, "no callcc"
-exclude :test_OR_in_order, "no callcc"
 exclude :test_permutation, "super flaky on travis"
 exclude :test_permutation_with_callcc, "no callcc"
 exclude :test_product_with_callcc, "no callcc"
@@ -16,6 +15,5 @@ exclude :test_shuffle_random, "gen conc modifies ary"
 exclude :test_sort_bang_with_freeze, ""
 exclude :test_sort_with_callcc, "no callcc"
 exclude :test_to_h, ""
-exclude :test_uniq_bang_with_freeze, ""
 exclude :test_values_at2, ""
 exclude :test_zip, ""
